@@ -126,7 +126,7 @@
     };
 
     PagedDisplay.prototype.layout = function(is_single_page) {
-      var adjust, body_style, bs, c, col_width, count, cprop, edge, fgcolor, first_layout, has_svg, n, only_img, priority, prop, rule, sheet, single_screen, sm, val, ww, _i, _j, _k, _l, _len, _len1, _len2, _len3, _ref, _ref1, _ref2, _ref3;
+      var adjust, body_style, body_width, bs, c, col_width, count, cprop, edge, fgcolor, first_layout, has_svg, n, only_img, priority, prop, rule, sheet, single_screen, sm, val, ww, _i, _j, _k, _l, _len, _len1, _len2, _len3, _ref, _ref1, _ref2, _ref3;
       if (is_single_page == null) {
         is_single_page = false;
       }
@@ -205,7 +205,8 @@
       if (first_layout) {
         has_svg = document.getElementsByTagName('svg').length > 0;
         only_img = document.getElementsByTagName('img').length === 1 && document.getElementsByTagName('div').length < 3 && document.getElementsByTagName('p').length < 2;
-        this.is_full_screen_layout = (only_img || has_svg) && single_screen && document.body.scrollWidth > document.body.clientWidth;
+        body_width = document.body.offsetWidth + 2 * sm;
+        this.is_full_screen_layout = (only_img || has_svg) && single_screen && document.body.scrollWidth > body_width && document.body.scrollWidth < 2 * body_width;
         if (is_single_page) {
           this.is_full_screen_layout = true;
         }
