@@ -6,7 +6,7 @@
 
 
 (function() {
-  var FontStats, font_dict, font_usage, log;
+  var FontStats, font_dict, font_usage, log, process_font_face_rule, process_sheet;
 
   if (typeof window !== "undefined" && window !== null ? window.calibre_utils : void 0) {
     log = window.calibre_utils.log;
@@ -55,6 +55,30 @@
     return ans;
   };
 
+  process_sheet = function(sheet, font_faces) {
+    var rule, _i, _len, _ref, _results;
+    _ref = sheet.cssRules;
+    _results = [];
+    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
+      rule = _ref[_i];
+      if (rule.type === rule.FONT_FACE_RULE) {
+        _results.push(process_font_face_rule(rule, font_faces));
+      } else if (rule.type === rule.IMPORT_RULE && rule.styleSheet) {
+        _results.push(process_sheet(rule.styleSheet, font_faces));
+      } else {
+        _results.push(void 0);
+      }
+    }
+    return _results;
+  };
+
+  process_font_face_rule = function(rule, font_faces) {
+    var fd;
+    fd = font_dict(rule.style);
+    fd['src'] = rule.style.getPropertyValue('src');
+    return font_faces.push(fd);
+  };
+
   FontStats = (function() {
 
     FontStats.name = 'FontStats';
@@ -66,20 +90,12 @@
     }
 
     FontStats.prototype.get_font_face_rules = function() {
-      var fd, font_faces, rule, sheet, _i, _j, _len, _len1, _ref, _ref1;
+      var font_faces, sheet, _i, _len, _ref;
       font_faces = [];
       _ref = document.styleSheets;
       for (_i = 0, _len = _ref.length; _i < _len; _i++) {
         sheet = _ref[_i];
-        _ref1 = sheet.cssRules;
-        for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
-          rule = _ref1[_j];
-          if (rule.type === rule.FONT_FACE_RULE) {
-            fd = font_dict(rule.style);
-            fd['src'] = rule.style.getPropertyValue('src');
-            font_faces.push(fd);
-          }
-        }
+        process_sheet(sheet, font_faces);
       }
       return py_bridge.value = font_faces;
     };
