@@ -223,8 +223,8 @@ per_language_title_sort_articles = {
         'spa'  : (r'El\s+', r'La\s+', r'Lo\s+', r'Los\s+', r'Las\s+', r'Un\s+',
                   r'Una\s+', r'Unos\s+', r'Unas\s+'),
         # French
-        'fra'  : (r'Le\s+', r'La\s+', r"L'", r'Les\s+', r'Un\s+', r'Une\s+',
-                  r'Des\s+', r'De\s+La\s+', r'De\s+', r"D'"),
+        'fra'  : (r'Le\s+', r'La\s+', r"L'", u'L´', r'Les\s+', r'Un\s+', r'Une\s+',
+                  r'Des\s+', r'De\s+La\s+', r'De\s+', r"D'", u'D´'),
         # Italian
         'ita'  : (r'Lo\s+', r'Il\s+', r"L'", r'La\s+', r'Gli\s+', r'I\s+',
                   r'Le\s+', ),
@@ -523,6 +523,14 @@ default_tweak_format = None
 # your library and your personal editing style.
 preselect_first_completion = False
 
+#: Completion mode when editing authors/tags/series/etc.
+# By default, when completing items, calibre will show you all the candidates
+# that start with the text you have already typed. You can instead have it show
+# all candidates that contain the text you have already typed. To do this, set
+# completion_mode to 'contains'. For example, if you type asi it will match both
+# Asimov and Quasimodo, whereas the default behavior would match only Asimov.
+completion_mode = 'prefix'
+
 #: Recognize numbers inside text when sorting
 # This means that when sorting on text fields like title the text "Book 2"
 # will sort before the text "Book 100". If you want this behavior, set
