@@ -70,15 +70,29 @@ if isosx:
 
 extensions = [
 
+    Extension('hunspell',
+              ['hunspell/'+x for x in
+                'affentry.cxx affixmgr.cxx csutil.cxx dictmgr.cxx filemgr.cxx hashmgr.cxx hunspell.cxx phonet.cxx replist.cxx suggestmgr.cxx'.split()
+                ] + ['calibre/utils/spell/hunspell_wrapper.cpp',],
+              inc_dirs=['hunspell'],
+              cflags='/DHUNSPELL_STATIC /D_CRT_SECURE_NO_WARNINGS /DUNICODE /D_UNICODE'.split() if iswindows else ['-DHUNSPELL_STATIC'],
+              optimize_level=2,
+              ),
+
     Extension('_regex',
               ['regex/_regex.c', 'regex/_regex_unicode.c'],
-              headers=['regex/_regex.h']
+              headers=['regex/_regex.h'],
+              optimize_level=2,
               ),
 
     Extension('speedup',
         ['calibre/utils/speedup.c'],
         ),
 
+    Extension('_patiencediff_c',
+        ['calibre/gui2/tweak_book/diff/_patiencediff_c.c'],
+        ),
+
     Extension('icu',
         ['calibre/utils/icu.c'],
         libraries=icu_libs,
@@ -418,7 +432,7 @@ class Build(Command):
             obj = self.j(obj_dir, os.path.splitext(self.b(src))[0]+'.o')
             objects.append(obj)
             if self.newer(obj, [src]+ext.headers):
-                inf = '/Tp' if src.endswith('.cpp') else '/Tc'
+                inf = '/Tp' if src.endswith('.cpp') or src.endswith('.cxx') else '/Tc'
                 sinc = [inf+src] if iswindows else ['-c', src]
                 oinc = ['/Fo'+obj] if iswindows else ['-o', obj]
                 cmd = [compiler] + cflags + ext.cflags + einc + sinc + oinc
