@@ -163,9 +163,10 @@ class Translations(POT):  # {{{
                 if self.newer(dest, iso639):
                     self.info('\tCopying ISO 639 translations for %s' % iscpo)
                     subprocess.check_call(['msgfmt', '-o', dest, iso639])
-            elif locale not in ('en_GB', 'en_CA', 'en_AU', 'si', 'ur', 'sc',
-                    'ltg', 'nds', 'te', 'yi', 'fo', 'sq', 'ast', 'ml', 'ku',
-                    'fr_CA', 'him', 'jv', 'ka', 'fur', 'ber', 'my'):
+            elif locale not in {
+                'en_GB', 'en_CA', 'en_AU', 'si', 'ur', 'sc', 'ltg', 'nds',
+                'te', 'yi', 'fo', 'sq', 'ast', 'ml', 'ku', 'fr_CA', 'him',
+                'jv', 'ka', 'fur', 'ber', 'my', 'fil'}:
                 self.warn('No ISO 639 translations for locale:', locale)
 
         if self.iso639_errors:
