@@ -4,7 +4,7 @@ __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal kovid@kovidgoyal.net'
 __docformat__ = 'restructuredtext en'
 __appname__   = u'calibre'
-numeric_version = (1, 14, 0)
+numeric_version = (1, 25, 0)
 __version__   = u'.'.join(map(unicode, numeric_version))
 __author__    = u"Kovid Goyal <kovid@kovidgoyal.net>"
 
@@ -139,7 +139,9 @@ class Plugins(collections.Mapping):
                 'woff',
                 'unrar',
                 'qt_hack',
-                '_regex'
+                '_regex',
+                'hunspell',
+                '_patiencediff_c',
             ]
         if iswindows:
             plugins.extend(['winutil', 'wpd', 'winfonts'])
