@@ -726,5 +726,21 @@ class ViewerPlugin(Plugin): # {{{
         '''
         pass
 
+    def customize_ui(self, ui):
+        '''
+        This method is called once when the viewer is created. Use it to make
+        any customizations you want to the viewer's user interface. For
+        example, you can modify the toolbars via ui.tool_bar and ui.tool_bar2.
+        '''
+        pass
+    def customize_context_menu(self, menu, event, hit_test_result):
+        '''
+        This method is called every time the context (right-click) menu is
+        shown. You can use it to customize the context menu. event is the
+        context menu event and hit_test_result is the QWebHitTestResult for this
+        event in the currently loaded document.
+        '''
+        pass
+
 # }}}
 
