@@ -428,6 +428,7 @@ class DB(object):
         defs['virtual_lib_on_startup'] = defs['cs_virtual_lib_on_startup'] = ''
         defs['virt_libs_hidden'] = defs['virt_libs_order'] = ()
         defs['update_all_last_mod_dates_on_start'] = False
+        defs['field_under_covers_in_grid'] = 'title'
 
         # Migrate the bool tristate tweak
         defs['bools_are_tristate'] = \
@@ -1234,7 +1235,12 @@ class DB(object):
                     f = lopen(path, 'rb')
                 except (IOError, OSError):
                     time.sleep(0.2)
-                f = lopen(path, 'rb')
+                try:
+                    f = lopen(path, 'rb')
+                except (IOError, OSError) as e:
+                    # Ensure the path that caused this error is reported
+                    raise Exception('Failed to open %r with error: %s' % (path, e))
+
                 with f:
                     if hasattr(dest, 'write'):
                         shutil.copyfileobj(f, dest)
