@@ -8,29 +8,43 @@ __license__   = 'GPL v3'
 __copyright__ = '2011, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
+from locale import atof
 from threading import Lock
 from collections import defaultdict, Counter
+from functools import partial
 
 from calibre.db.tables import ONE_ONE, MANY_ONE, MANY_MANY, null
 from calibre.db.write import Writer
-from calibre.ebooks.metadata import title_sort
+from calibre.db.utils import force_to_bool
+from calibre.ebooks.metadata import title_sort, author_to_author_sort
 from calibre.utils.config_base import tweaks
 from calibre.utils.icu import sort_key
-from calibre.utils.date import UNDEFINED_DATE
+from calibre.utils.date import UNDEFINED_DATE, clean_date_for_sort, parse_date
 from calibre.utils.localization import calibre_langcode_to_name
 
+def bool_sort_key(bools_are_tristate):
+    return (lambda x:{True: 1, False: 2, None: 3}.get(x, 3)) if bools_are_tristate else lambda x:{True: 1, False: 2, None: 2}.get(x, 2)
+
+IDENTITY = lambda x: x
+
+class InvalidLinkTable(Exception):
+
+    def __init__(self, name):
+        Exception.__init__(self, name)
+        self.field_name = name
+
 class Field(object):
 
     is_many = False
     is_many_many = False
     is_composite = False
 
-    def __init__(self, name, table):
+    def __init__(self, name, table, bools_are_tristate):
         self.name, self.table = name, table
         dt = self.metadata['datatype']
         self.has_text_data = dt in {'text', 'comments', 'series', 'enumeration'}
         self.table_type = self.table.table_type
-        self._sort_key = (sort_key if dt in ('text', 'series', 'enumeration') else lambda x: x)
+        self._sort_key = (sort_key if dt in ('text', 'series', 'enumeration') else IDENTITY)
 
         # This will be compared to the output of sort_key() which is a
         # bytestring, therefore it is safer to have it be a bytestring.
@@ -42,12 +56,25 @@ class Field(object):
             self._default_sort_key = 0
         elif dt == 'bool':
             self._default_sort_key = None
+            self._sort_key = bool_sort_key(bools_are_tristate)
         elif dt == 'datetime':
             self._default_sort_key = UNDEFINED_DATE
+            if tweaks['sort_dates_using_visible_fields']:
+                fmt = None
+                if name in {'timestamp', 'pubdate', 'last_modified'}:
+                    fmt = tweaks['gui_%s_display_format' % name]
+                elif self.metadata['is_custom']:
+                    fmt = self.metadata.get('display', {}).get('date_format', None)
+                self._sort_key = partial(clean_date_for_sort, fmt=fmt)
+
         if self.name == 'languages':
             self._sort_key = lambda x:sort_key(calibre_langcode_to_name(x))
         self.is_multiple = (bool(self.metadata['is_multiple']) or self.name ==
                 'formats')
+        self.sort_sort_key = True
+        if self.is_multiple and '&' in self.metadata['is_multiple']['list_to_ui']:
+            self._sort_key = lambda x: sort_key(author_to_author_sort(x))
+            self.sort_sort_key = False
         self.default_value = {} if name == 'identifiers' else () if self.is_multiple else None
         self.category_formatter = type(u'')
         if dt == 'rating':
@@ -93,12 +120,11 @@ class Field(object):
         '''
         return iter(())
 
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
+    def sort_keys_for_books(self, get_metadata, lang_map):
         '''
-        Return a mapping of book_id -> sort_key. The sort key is suitable for
+        Return a function that maps book_id to sort_key. The sort key is suitable for
         use in sorting the list of all books by this field, via the python cmp
-        method. all_book_ids is the list/set of book ids for which sort_keys
-        should be generated.
+        method.
         '''
         raise NotImplementedError()
 
@@ -124,9 +150,15 @@ class Field(object):
                 ratings = tuple(r for r in (book_rating_map.get(book_id, 0) for
                                             book_id in item_book_ids) if r > 0)
                 avg = sum(ratings)/len(ratings) if ratings else 0
-                name = self.category_formatter(id_map[item_id])
+                try:
+                    name = self.category_formatter(id_map[item_id])
+                except KeyError:
+                    # db has entries in the link table without entries in the
+                    # id table, for example, see
+                    # https://bugs.launchpad.net/bugs/1218783
+                    raise InvalidLinkTable(self.name)
                 sval = (self.category_sort_value(item_id, item_book_ids, lang_map)
-                        if special_sort else name)
+                    if special_sort else name)
                 c = tag_class(name, id=item_id, sort=sval, avg=avg,
                               id_set=item_book_ids, count=len(item_book_ids))
                 ans.append(c)
@@ -146,9 +178,13 @@ class OneToOneField(Field):
     def __iter__(self):
         return self.table.book_col_map.iterkeys()
 
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
-        return {id_: self._sort_key(self.table.book_col_map.get(id_,
-            self._default_sort_key)) for id_ in all_book_ids}
+    def sort_keys_for_books(self, get_metadata, lang_map):
+        bcmg = self.table.book_col_map.get
+        dk = self._default_sort_key
+        sk = self._sort_key
+        if sk is IDENTITY:
+            return lambda book_id:bcmg(book_id, dk)
+        return lambda book_id:sk(bcmg(book_id, dk))
 
     def iter_searchable_values(self, get_metadata, candidates, default_value=None):
         cbm = self.table.book_col_map
@@ -158,13 +194,64 @@ class OneToOneField(Field):
 class CompositeField(OneToOneField):
 
     is_composite = True
+    SIZE_SUFFIX_MAP = {suffix:i for i, suffix in enumerate(('', 'K', 'M', 'G', 'T', 'P', 'E'))}
 
-    def __init__(self, *args, **kwargs):
-        OneToOneField.__init__(self, *args, **kwargs)
+    def __init__(self, name, table, bools_are_tristate):
+        OneToOneField.__init__(self, name, table, bools_are_tristate)
 
         self._render_cache = {}
         self._lock = Lock()
-        self._composite_name = '#' + self.metadata['label']
+        m = self.metadata
+        self._composite_name = '#' + m['label']
+        try:
+            self.splitter = m['is_multiple'].get('cache_to_list', None)
+        except AttributeError:
+            self.splitter = None
+        composite_sort = m.get('display', {}).get('composite_sort', None)
+        if composite_sort == 'number':
+            self._default_sort_key = 0
+            self._sort_key = self.number_sort_key
+        elif composite_sort == 'date':
+            self._default_sort_key = UNDEFINED_DATE
+            self._filter_date = lambda x: x
+            if tweaks['sort_dates_using_visible_fields']:
+                fmt = m.get('display', {}).get('date_format', None)
+                self._filter_date = partial(clean_date_for_sort, fmt=fmt)
+            self._sort_key = self.date_sort_key
+        elif composite_sort == 'bool':
+            self._default_sort_key = None
+            self._bool_sort_key = bool_sort_key(bools_are_tristate)
+            self._sort_key = self.bool_sort_key
+        elif self.splitter is not None:
+            self._default_sort_key = ()
+            self._sort_key = self.multiple_sort_key
+        else:
+            self._sort_key = sort_key
+
+    def multiple_sort_key(self, val):
+        val = (sort_key(x.strip()) for x in (val or '').split(self.splitter))
+        return tuple(sorted(val))
+
+    def number_sort_key(self, val):
+        try:
+            p = 1
+            if val and val.endswith('B'):
+                p = 1 << (10 * self.SIZE_SUFFIX_MAP.get(val[-2:-1], 0))
+                val = val[:(-2 if p > 1 else -1)].strip()
+            val = atof(val) * p
+        except (TypeError, AttributeError, ValueError, KeyError):
+            val = 0.0
+        return val
+
+    def date_sort_key(self, val):
+        try:
+            val = self._filter_date(parse_date(val))
+        except (TypeError, ValueError, AttributeError, KeyError):
+            val = UNDEFINED_DATE
+        return val
+
+    def bool_sort_key(self, val):
+        return self._bool_sort_key(force_to_bool(val))
 
     def render_composite(self, book_id, mi):
         with self._lock:
@@ -193,14 +280,22 @@ class CompositeField(OneToOneField):
                 self._render_cache[book_id] = ans
         return ans
 
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
-        return {id_: sort_key(self.get_value_with_cache(id_, get_metadata)) for id_ in
-                all_book_ids}
+    def sort_keys_for_books(self, get_metadata, lang_map):
+        gv = self.get_value_with_cache
+        sk = self._sort_key
+        if sk is IDENTITY:
+            return lambda book_id:gv(book_id, get_metadata)
+        return lambda book_id:sk(gv(book_id, get_metadata))
 
     def iter_searchable_values(self, get_metadata, candidates, default_value=None):
         val_map = defaultdict(set)
+        splitter = self.splitter
         for book_id in candidates:
-            val_map[self.get_value_with_cache(book_id, get_metadata)].add(book_id)
+            vals = self.get_value_with_cache(book_id, get_metadata)
+            vals = (vv.strip() for vv in vals.split(splitter)) if splitter else (vals,)
+            for v in vals:
+                if v:
+                    val_map[v].add(book_id)
         for val, book_ids in val_map.iteritems():
             yield val, book_ids
 
@@ -235,7 +330,7 @@ class CompositeField(OneToOneField):
 
 class OnDeviceField(OneToOneField):
 
-    def __init__(self, name, table):
+    def __init__(self, name, table, bools_are_tristate):
         self.name = name
         self.book_on_device_func = None
         self.is_multiple = False
@@ -287,9 +382,8 @@ class OnDeviceField(OneToOneField):
     def __iter__(self):
         return iter(())
 
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
-        return {id_: self.for_book(id_) for id_ in
-                all_book_ids}
+    def sort_keys_for_books(self, get_metadata, lang_map):
+        return self.for_book
 
     def iter_searchable_values(self, get_metadata, candidates, default_value=None):
         val_map = defaultdict(set)
@@ -298,6 +392,27 @@ class OnDeviceField(OneToOneField):
         for val, book_ids in val_map.iteritems():
             yield val, book_ids
 
+class LazySortMap(object):
+
+    __slots__ = ('default_sort_key', 'sort_key_func', 'id_map', 'cache')
+
+    def __init__(self, default_sort_key, sort_key_func, id_map):
+        self.default_sort_key = default_sort_key
+        self.sort_key_func = sort_key_func
+        self.id_map = id_map
+        self.cache = {None:default_sort_key}
+
+    def __call__(self, item_id):
+        try:
+            return self.cache[item_id]
+        except KeyError:
+            try:
+                val = self.cache[item_id] = self.sort_key_func(self.id_map[item_id])
+            except KeyError:
+                val = self.cache[item_id] = self.default_sort_key
+            return val
+
+
 class ManyToOneField(Field):
 
     is_many = True
@@ -322,13 +437,10 @@ class ManyToOneField(Field):
     def __iter__(self):
         return self.table.id_map.iterkeys()
 
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
-        ans = {id_: self.table.book_col_map.get(id_, None)
-                for id_ in all_book_ids}
-        sk_map = {cid: (self._default_sort_key if cid is None else
-                self._sort_key(self.table.id_map[cid]))
-                for cid in ans.itervalues()}
-        return {id_: sk_map[cid] for id_, cid in ans.iteritems()}
+    def sort_keys_for_books(self, get_metadata, lang_map):
+        sk_map = LazySortMap(self._default_sort_key, self._sort_key, self.table.id_map)
+        bcmg = self.table.book_col_map.get
+        return lambda book_id:sk_map(bcmg(book_id, None))
 
     def iter_searchable_values(self, get_metadata, candidates, default_value=None):
         cbm = self.table.col_book_map
@@ -340,8 +452,11 @@ class ManyToOneField(Field):
 
     @property
     def book_value_map(self):
-        return {book_id:self.table.id_map[item_id] for book_id, item_id in
+        try:
+            return {book_id:self.table.id_map[item_id] for book_id, item_id in
                 self.table.book_col_map.iteritems()}
+        except KeyError:
+            raise InvalidLinkTable(self.name)
 
 class ManyToManyField(Field):
 
@@ -372,17 +487,17 @@ class ManyToManyField(Field):
     def __iter__(self):
         return self.table.id_map.iterkeys()
 
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
-        ans = {id_: self.table.book_col_map.get(id_, ())
-                for id_ in all_book_ids}
-        all_cids = set()
-        for cids in ans.itervalues():
-            all_cids = all_cids.union(set(cids))
-        sk_map = {cid: self._sort_key(self.table.id_map[cid])
-                for cid in all_cids}
-        return {id_: (tuple(sk_map[cid] for cid in cids) if cids else
-                        (self._default_sort_key,))
-                for id_, cids in ans.iteritems()}
+    def sort_keys_for_books(self, get_metadata, lang_map):
+        sk_map = LazySortMap(self._default_sort_key, self._sort_key, self.table.id_map)
+        bcmg = self.table.book_col_map.get
+        dsk = (self._default_sort_key,)
+        if self.sort_sort_key:
+            def sk(book_id):
+                return tuple(sorted(sk_map(x) for x in bcmg(book_id, ()))) or dsk
+        else:
+            def sk(book_id):
+                return tuple(sk_map(x) for x in bcmg(book_id, ())) or dsk
+        return sk
 
     def iter_searchable_values(self, get_metadata, candidates, default_value=None):
         cbm = self.table.col_book_map
@@ -402,8 +517,11 @@ class ManyToManyField(Field):
 
     @property
     def book_value_map(self):
-        return {book_id:tuple(self.table.id_map[item_id] for item_id in item_ids)
+        try:
+            return {book_id:tuple(self.table.id_map[item_id] for item_id in item_ids)
                 for book_id, item_ids in self.table.book_col_map.iteritems()}
+        except KeyError:
+            raise InvalidLinkTable(self.name)
 
 class IdentifiersField(ManyToManyField):
 
@@ -416,13 +534,11 @@ class IdentifiersField(ManyToManyField):
                 ids = default_value
         return ids
 
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
+    def sort_keys_for_books(self, get_metadata, lang_map):
         'Sort by identifier keys'
-        ans = {id_: self.table.book_col_map.get(id_, ())
-                for id_ in all_book_ids}
-        return {id_: (tuple(sorted(cids.iterkeys())) if cids else
-                        (self._default_sort_key,))
-                for id_, cids in ans.iteritems()}
+        bcmg = self.table.book_col_map.get
+        dv = {self._default_sort_key:None}
+        return lambda book_id: tuple(sorted(bcmg(book_id, dv).iterkeys()))
 
     def iter_searchable_values(self, get_metadata, candidates, default_value=()):
         bcm = self.table.book_col_map
@@ -491,22 +607,43 @@ class FormatsField(ManyToManyField):
                 ans.append(c)
         return ans
 
+class LazySeriesSortMap(object):
+
+    __slots__ = ('default_sort_key', 'sort_key_func', 'id_map', 'cache')
+
+    def __init__(self, default_sort_key, sort_key_func, id_map):
+        self.default_sort_key = default_sort_key
+        self.sort_key_func = sort_key_func
+        self.id_map = id_map
+        self.cache = {}
+
+    def __call__(self, item_id, lang):
+        try:
+            return self.cache[(item_id, lang)]
+        except KeyError:
+            try:
+                val = self.cache[(item_id, lang)] = self.sort_key_func(self.id_map[item_id], lang)
+            except KeyError:
+                val = self.cache[(item_id, lang)] = self.default_sort_key
+            return val
+
 class SeriesField(ManyToOneField):
 
-    def sort_key_for_series(self, book_id, lang_map, series_sort_order):
-        sid = self.table.book_col_map.get(book_id, None)
-        if sid is None:
-            return self._default_sort_key
-        lang = lang_map.get(book_id, None) or None
-        if lang:
-            lang = lang[0]
-        return self._sort_key(title_sort(self.table.id_map[sid],
-                                         order=series_sort_order, lang=lang))
-
-    def sort_keys_for_books(self, get_metadata, lang_map, all_book_ids):
+    def sort_keys_for_books(self, get_metadata, lang_map):
         sso = tweaks['title_series_sorting']
-        return {book_id:self.sort_key_for_series(book_id, lang_map, sso) for book_id
-                in all_book_ids}
+        ssk = self._sort_key
+        ts = title_sort
+        def sk(val, lang):
+            return ssk(ts(val, order=sso, lang=lang))
+        sk_map = LazySeriesSortMap(self._default_sort_key, sk, self.table.id_map)
+        bcmg = self.table.book_col_map.get
+        lang_map = {k:v[0] if v else None for k, v in lang_map.iteritems()}
+
+        def key(book_id):
+            lang = lang_map.get(book_id, None)
+            return sk_map(bcmg(book_id, None), lang)
+
+        return key
 
     def category_sort_value(self, item_id, book_ids, lang_map):
         lang = None
@@ -552,7 +689,7 @@ class TagsField(ManyToManyField):
                 ans.append(c)
         return ans
 
-def create_field(name, table):
+def create_field(name, table, bools_are_tristate):
     cls = {
             ONE_ONE: OneToOneField,
             MANY_ONE: ManyToOneField,
@@ -572,5 +709,5 @@ def create_field(name, table):
         cls = CompositeField
     elif table.metadata['datatype'] == 'series':
         cls = SeriesField
-    return cls(name, table)
+    return cls(name, table, bools_are_tristate)
 
