@@ -61,11 +61,7 @@ class TestResult(unittest.TextTestResult):
 def find_tests():
     return unittest.defaultTestLoader.discover(os.path.dirname(os.path.abspath(__file__)), pattern='*.py')
 
-if __name__ == '__main__':
-    from calibre.utils.config_base import reset_tweaks_to_default
-    from calibre.ebooks.metadata.book.base import reset_field_metadata
-    reset_tweaks_to_default()
-    reset_field_metadata()
+def run_tests(find_tests=find_tests):
     parser = argparse.ArgumentParser()
     parser.add_argument('name', nargs='?', default=None,
                         help='The name of the test to run, for e.g. writing.WritingTest.many_many_basic or .many_many_basic for a shortcut')
@@ -79,6 +75,8 @@ if __name__ == '__main__':
         try:
             for suite in tests:
                 for test in suite._tests:
+                    if test.__class__.__name__ == 'ModuleImportFailure':
+                        raise Exception('Failed to import a test module: %s' % test)
                     for s in test:
                         if s._testMethodName == q:
                             ans = s
@@ -95,3 +93,10 @@ if __name__ == '__main__':
     r.resultclass = TestResult
     r(verbosity=4).run(tests)
 
+if __name__ == '__main__':
+    from calibre.utils.config_base import reset_tweaks_to_default
+    from calibre.ebooks.metadata.book.base import reset_field_metadata
+    reset_tweaks_to_default()
+    reset_field_metadata()
+    run_tests()
+
