@@ -13,7 +13,7 @@ from itertools import izip, imap
 from future_builtins import map
 
 from calibre.ebooks.metadata import title_sort
-from calibre.utils.config_base import tweaks
+from calibre.utils.config_base import tweaks, prefs
 from calibre.db.write import uniq
 
 def sanitize_sort_field_name(field_metadata, field):
@@ -77,6 +77,7 @@ class View(object):
     def __init__(self, cache):
         self.cache = cache
         self.marked_ids = {}
+        self.marked_listeners = {}
         self.search_restriction_book_count = 0
         self.search_restriction = self.base_restriction = ''
         self.search_restriction_name = self.base_restriction_name = ''
@@ -127,6 +128,9 @@ class View(object):
         self.full_map_is_sorted = True
         self.sort_history = [('id', True)]
 
+    def add_marked_listener(self, func):
+        self.marked_listeners[id(func)] = weakref.ref(func)
+
     def add_to_sort_history(self, items):
         self.sort_history = uniq((list(items) + list(self.sort_history)),
                                  operator.itemgetter(0))[:tweaks['maximum_resort_levels']]
@@ -201,7 +205,7 @@ class View(object):
 
     def get_series_sort(self, idx, index_is_id=True, default_value=''):
         book_id = idx if index_is_id else self.index_to_id(idx)
-        with self.cache.read_lock:
+        with self.cache.safe_read_lock:
             lang_map = self.cache.fields['languages'].book_value_map
             lang = lang_map.get(book_id, None) or None
             if lang:
@@ -219,7 +223,7 @@ class View(object):
 
     def get_author_data(self, idx, index_is_id=True, default_value=None):
         id_ = idx if index_is_id else self.index_to_id(idx)
-        with self.cache.read_lock:
+        with self.cache.safe_read_lock:
             ids = self.cache._field_ids_for('authors', id_)
             adata = self.cache._author_data(ids)
             ans = [':::'.join((adata[aid]['name'], adata[aid]['sort'], adata[aid]['link'])) for aid in ids if aid in adata]
@@ -370,7 +374,19 @@ class View(object):
                 id_dict.itervalues())))
         # This invalidates all searches in the cache even though the cache may
         # be shared by multiple views. This is not ideal, but...
-        self.cache.clear_search_caches(old_marked_ids | set(self.marked_ids))
+        cmids = set(self.marked_ids)
+        self.cache.clear_search_caches(old_marked_ids | cmids)
+        if old_marked_ids != cmids:
+            for funcref in self.marked_listeners.itervalues():
+                func = funcref()
+                if func is not None:
+                    func(old_marked_ids, cmids)
+
+    def toggle_marked_ids(self, book_ids):
+        book_ids = set(book_ids)
+        mids = set(self.marked_ids)
+        common = mids.intersection(book_ids)
+        self.set_marked_ids((mids | book_ids) - common)
 
     def refresh(self, field=None, ascending=True, clear_caches=True, do_search=True):
         self._map = tuple(sorted(self.cache.all_book_ids()))
@@ -410,4 +426,6 @@ class View(object):
         ids = tuple(ids)
         self._map = ids + self._map
         self._map_filtered = ids + self._map_filtered
+        if prefs['mark_new_books']:
+            self.toggle_marked_ids(ids)
 
