@@ -46,14 +46,14 @@ class Worker(Thread):  # Get details {{{
 
         months = {
                 'de': {
-            1: ['jän'],
+            1: ['jän', 'januar'],
             2: ['februar'],
             3: ['märz'],
             5: ['mai'],
             6: ['juni'],
             7: ['juli'],
-            10: ['okt'],
-            12: ['dez']
+            10: ['okt', 'oktober'],
+            12: ['dez', 'dezember']
             },
                 'it': {
             1: ['enn'],
@@ -436,6 +436,11 @@ class Worker(Thread):  # Get details {{{
         return authors
 
     def parse_rating(self, root):
+        for x in root.xpath('//div[@id="cpsims-feature" or @id="purchase-sims-feature" or @id="rhf"]'):
+            # Remove the similar books section as it can cause sppurious
+            # ratings matches
+            x.getparent().remove(x)
+
         rating_paths = ('//div[@data-feature-name="averageCustomerReviews"]',
                         '//div[@class="jumpBar"]/descendant::span[contains(@class,"asinReviewsSummary")]',
                         '//div[@class="buying"]/descendant::span[contains(@class,"asinReviewsSummary")]',
