@@ -35,10 +35,10 @@ class ISBNDB(Source):
                     'at isbndb.com and get an access key.')),
             )
 
-    config_help_message = '<p>'+_('To use metadata from isbndb.com you must sign'
+    config_help_message = ('<p>'+_('To use metadata from isbndb.com you must sign'
             ' up for a free account and get an isbndb key and enter it below.'
             ' Instructions to get the key are '
-            '<a href="http://isbndb.com/docs/api/30-keys.html">here</a>.')
+            '<a href="%s">here</a>.')) % 'http://isbndb.com/api/v1/docs/keys'
 
 
     def __init__(self, *args, **kwargs):
