@@ -19,7 +19,7 @@ class OpenLibrary(Source):
     OPENLIBRARY = 'http://covers.openlibrary.org/b/isbn/%s-L.jpg?default=false'
 
     def download_cover(self, log, result_queue, abort,
-            title=None, authors=None, identifiers={}, timeout=30):
+            title=None, authors=None, identifiers={}, timeout=30, get_best_cover=False):
         if 'isbn' not in identifiers:
             return
         isbn = identifiers['isbn']
