@@ -204,6 +204,11 @@ class Mobi8Reader(object):
                 baseptr = baseptr + length
                 divptr += 1
             self.parts.append(skeleton)
+            if divcnt < 1:
+                # Empty file
+                import uuid
+                aidtext = str(uuid.uuid4())
+                filename = aidtext + '.html'
             self.partinfo.append(Part(skelnum, 'text', filename, skelpos,
                 baseptr, aidtext))
 
@@ -381,6 +386,7 @@ class Mobi8Reader(object):
         return build_toc(index_entries)
 
     def extract_resources(self):
+        from calibre.ebooks.mobi.writer2.resources import PLACEHOLDER_GIF
         resource_map = []
         for x in ('fonts', 'images'):
             os.mkdir(x)
@@ -409,16 +415,17 @@ class Mobi8Reader(object):
                 if font['encrypted']:
                     self.encrypted_fonts.append(href)
             else:
-                imgtype = what(None, data)
-                if imgtype is None:
-                    from calibre.utils.magick.draw import identify_data
-                    try:
-                        imgtype = identify_data(data)[2]
-                    except Exception:
-                        imgtype = 'unknown'
-                href = 'images/%05d.%s'%(fname_idx, imgtype)
-                with open(href.replace('/', os.sep), 'wb') as f:
-                    f.write(data)
+                if not (len(data) == len(PLACEHOLDER_GIF) and data == PLACEHOLDER_GIF):
+                    imgtype = what(None, data)
+                    if imgtype is None:
+                        from calibre.utils.magick.draw import identify_data
+                        try:
+                            imgtype = identify_data(data)[2]
+                        except Exception:
+                            imgtype = 'unknown'
+                    href = 'images/%05d.%s'%(fname_idx, imgtype)
+                    with open(href.replace('/', os.sep), 'wb') as f:
+                        f.write(data)
 
             resource_map.append(href)
 
@@ -453,6 +460,9 @@ class Mobi8Reader(object):
             return os.path.basename(path) == 'debug-raw.html'
 
         opf.create_manifest_from_files_in([os.getcwdu()], exclude=exclude)
+        for entry in opf.manifest:
+            if entry.mime_type == 'text/html':
+                entry.mime_type = 'application/xhtml+xml'
         opf.create_spine(spine)
         opf.set_toc(toc)
         ppd = self.resc_data.get('page-progression-direction', None)
