@@ -138,6 +138,8 @@ class MOBIHeader(Header): # {{{
     unknown2 = zeroes(8)
 
     # 192: FDST
+    # In MOBI 6 the fdst record is instead two two byte fields storing the
+    # index of the first and last content records
     fdst_record = DYN
     fdst_count = DYN
 
@@ -275,6 +277,8 @@ class KF8Book(object):
         self.exth_flags = 0b1010000
         if writer.opts.mobi_periodical:
             self.exth_flags |= 0b1000
+        if resources.has_fonts:
+            self.exth_flags |= 0b1000000000000
 
         self.opts = writer.opts
         self.start_offset = writer.start_offset
