@@ -38,12 +38,13 @@ XLINK_NS     = 'http://www.w3.org/1999/xlink'
 CALIBRE_NS   = 'http://calibre.kovidgoyal.net/2009/metadata'
 RE_NS        = 'http://exslt.org/regular-expressions'
 MBP_NS       = 'http://www.mobipocket.com'
+EPUB_NS      = 'http://www.idpf.org/2007/ops'
 
 XPNSMAP      = {'h': XHTML_NS, 'o1': OPF1_NS, 'o2': OPF2_NS,
                 'd09': DC09_NS, 'd10': DC10_NS, 'd11': DC11_NS,
                 'xsi': XSI_NS, 'dt': DCTERMS_NS, 'ncx': NCX_NS,
                 'svg': SVG_NS, 'xl': XLINK_NS, 're': RE_NS,
-                'mbp': MBP_NS, 'calibre': CALIBRE_NS}
+                'mbp': MBP_NS, 'calibre': CALIBRE_NS, 'epub':EPUB_NS}
 
 OPF1_NSMAP   = {'dc': DC11_NS, 'oebpackage': OPF1_NS}
 OPF2_NSMAP   = {'opf': OPF2_NS, 'dc': DC11_NS, 'dcterms': DCTERMS_NS,
