@@ -41,8 +41,8 @@ def get_page_size(opts, for_comic=False):  # {{{
             width, sep, height = opts.custom_size.partition('x')
             if height:
                 try:
-                    width = float(width)
-                    height = float(height)
+                    width = float(width.replace(',', '.'))
+                    height = float(height.replace(',', '.'))
                 except:
                     pass
                 else:
@@ -209,7 +209,7 @@ class PDFWriter(QObject):
         self.painter = QPainter(self.doc)
         self.doc.set_metadata(title=pdf_metadata.title,
                               author=pdf_metadata.author,
-                              tags=pdf_metadata.tags)
+                              tags=pdf_metadata.tags, mi=pdf_metadata.mi)
         self.doc_title = pdf_metadata.title
         self.doc_author = pdf_metadata.author
         self.painter.save()
