@@ -106,7 +106,7 @@ class TextileMLizer(OEB2HTML):
         #correct blockcode paras
         text = re.sub(r'\npre\.\n?\nbc\.', r'\nbc.', text)
         #correct blockquote paras
-        text = re.sub(r'\nbq\.\n?\np.*\. ', r'\nbq. ', text)
+        text = re.sub(r'\nbq\.\n?\np.*?\. ', r'\nbq. ', text)
 
         #reduce blank lines
         text = re.sub(r'\n{3}', r'\n\np. \n\n', text)
@@ -241,6 +241,8 @@ class TextileMLizer(OEB2HTML):
         # Ignore anything that is set to not be displayed.
         if style['display'] in ('none', 'oeb-page-head', 'oeb-page-foot') \
            or style['visibility'] == 'hidden':
+            if hasattr(elem, 'tail') and elem.tail:
+                return [elem.tail]
             return ['']
 
         # Soft scene breaks.
