@@ -11,8 +11,8 @@ from calibre.gui2.actions import InterfaceAction
 class OpenFolderAction(InterfaceAction):
 
     name = 'Open Folder'
-    action_spec = (_('Open containing folder'), 'document_open.png', None,
-            _('O'))
+    action_spec = (_('Open containing folder'), 'document_open.png',
+                   _('Open the folder containing the current book\'s files'), _('O'))
     dont_add_to = frozenset(['context-menu-device'])
     action_type = 'current'
 
