@@ -19,10 +19,10 @@ class Choose(QDialog):
         QDialog.__init__(self, parent)
         self.l = l = QVBoxLayout(self)
         self.setLayout(l)
-        self.setWindowTitle(_('Choose format to tweak'))
+        self.setWindowTitle(_('Choose format to edit'))
 
         self.la = la = QLabel(_(
-            'This book mas multiple formats that can be tweaked. Choose the format you want to tweak.'))
+            'This book has multiple formats that can be edited. Choose the format you want to edit.'))
         l.addWidget(la)
 
         self.rem = QCheckBox(_('Always ask when more than one format is available'))
@@ -54,7 +54,7 @@ class Choose(QDialog):
 class TweakEpubAction(InterfaceAction):
 
     name = 'Tweak ePub'
-    action_spec = (_('Tweak Book'), 'tweak.png', _('Edit eBooks'), _('T'))
+    action_spec = (_('Edit Book'), 'tweak.png', _('Edit eBooks'), _('T'))
     dont_add_to = frozenset(['context-menu-device'])
     action_type = 'current'
 
@@ -90,27 +90,25 @@ class TweakEpubAction(InterfaceAction):
     def tweak_book(self):
         row = self.gui.library_view.currentIndex()
         if not row.isValid():
-            return error_dialog(self.gui, _('Cannot Tweak Book'),
+            return error_dialog(self.gui, _('Cannot Edit Book'),
                     _('No book selected'), show=True)
 
         book_id = self.gui.library_view.model().id(row)
         self.do_tweak(book_id)
 
     def do_tweak(self, book_id):
-        from calibre.utils.config_base import tweaks
-        if not tweaks.get('test_tweak_book', False):
-            return self.gui.iactions['Unpack Book'].do_tweak(book_id)
         from calibre.ebooks.oeb.polish.main import SUPPORTED
         db = self.gui.library_view.model().db
         fmts = db.formats(book_id, index_is_id=True) or ''
         fmts = [x.upper().strip() for x in fmts.split(',')]
         tweakable_fmts = set(fmts).intersection(SUPPORTED)
         if not tweakable_fmts:
-            return error_dialog(self.gui, _('Cannot Tweak Book'),
-                    _('The book must be in the %s formats to tweak.'
+            return error_dialog(self.gui, _('Cannot Edit Book'),
+                    _('The book must be in the %s formats to edit.'
                         '\n\nFirst convert the book to one of these formats.') % (_(' or '.join(SUPPORTED))),
                     show=True)
         from calibre.gui2.tweak_book import tprefs
+        tprefs.refresh()  # In case they were changed in a Tweak Book process
         if len(tweakable_fmts) > 1:
             if tprefs['choose_tweak_fmt']:
                 d = Choose(sorted(tweakable_fmts, key=tprefs.defaults['tweak_fmt_order'].index), self.gui)
@@ -129,16 +127,17 @@ class TweakEpubAction(InterfaceAction):
             return error_dialog(self.gui, _('File missing'), _(
                 'The %s format is missing from the calibre library. You should run'
                 ' library maintenance.') % fmt, show=True)
-        tweak = 'ebook-tweak'
+        tweak = 'ebook-edit'
         self.gui.setCursor(Qt.BusyCursor)
         if tprefs['update_metadata_from_calibre']:
             from calibre.ebooks.metadata.opf2 import pretty_print
             from calibre.ebooks.metadata.meta import set_metadata
-            mi = db.new_api.get_metadata(book_id)
+            mi = db.new_api.get_metadata(book_id, get_cover=True)
             with pretty_print, open(path, 'r+b') as f:
                 set_metadata(f, mi, stream_type=fmt.lower())
+        notify = '%d:%s:%s:%s' % (book_id, fmt, db.library_id, db.library_path)
         try:
-            self.gui.job_manager.launch_gui_app(tweak, kwargs=dict(args=[tweak, path]))
+            self.gui.job_manager.launch_gui_app(tweak, kwargs=dict(path=path, notify=notify))
             time.sleep(2)
         finally:
             self.gui.unsetCursor()
