@@ -20,6 +20,14 @@ from calibre.gui2.dialogs.duplicates import DuplicatesQuestion
 
 AUTO_ADDED = frozenset(BOOK_EXTENSIONS) - {'pdr', 'mbp', 'tan'}
 
+class AllAllowed(object):
+
+    def __init__(self):
+        self.disallowed = frozenset(gprefs['blocked_auto_formats'])
+
+    def __contains__(self, x):
+        return x not in self.disallowed
+
 class Worker(Thread):
 
     def __init__(self, path, callback):
@@ -29,7 +37,10 @@ class Worker(Thread):
         self.wake_up = Event()
         self.path, self.callback = path, callback
         self.staging = set()
-        self.allowed = AUTO_ADDED - frozenset(gprefs['blocked_auto_formats'])
+        if gprefs['auto_add_everything']:
+            self.allowed = AllAllowed()
+        else:
+            self.allowed = AUTO_ADDED - frozenset(gprefs['blocked_auto_formats'])
 
     def run(self):
         self.tdir = PersistentTemporaryDirectory('_auto_adder')
@@ -210,7 +221,8 @@ class AutoAdder(QObject):
                 os.remove(paths[0])
                 self.worker.staging.remove(fname)
             except:
-                pass
+                import traceback
+                traceback.print_exc()
             count += num
 
         if duplicates:
