@@ -17,7 +17,7 @@ class PluginWidget(Widget, Ui_Form):
     TITLE = _('AZW3 Output')
     HELP = _('Options specific to')+' AZW3 '+_('output')
     COMMIT_NAME = 'azw3_output'
-    ICON = I('mimetypes/mobi.png')
+    ICON = I('mimetypes/azw3.png')
 
     def __init__(self, parent, get_option, get_help, db=None, book_id=None):
         Widget.__init__(self, parent,
