@@ -38,7 +38,7 @@ class LookAndFeelWidget(Widget, Ui_Form):
                     'remove_paragraph_spacing',
                     'remove_paragraph_spacing_indent_size',
                     'insert_blank_line_size',
-                    'input_encoding', 'filter_css',
+                    'input_encoding', 'filter_css', 'expand_css',
                     'asciiize', 'keep_ligatures',
                     'linearize_tables']
                 )
