@@ -10,12 +10,11 @@ __docformat__ = 'restructuredtext en'
 from operator import attrgetter
 
 from PyQt4.Qt import (QTabWidget, QTreeWidget, QTreeWidgetItem, Qt, QDialog,
-        QDialogButtonBox, QVBoxLayout, QSize, pyqtSignal, QIcon, QLabel,
-        QListWidget, QListWidgetItem)
+        QDialogButtonBox, QVBoxLayout, QSize, pyqtSignal, QIcon, QLabel)
 
 from calibre.gui2 import file_icon_provider
 
-def item(f, parent):
+def browser_item(f, parent):
     name = f.name
     if not f.is_folder:
         name += ' [%s]'%f.last_mod_string
@@ -31,22 +30,24 @@ def item(f, parent):
 
 class Storage(QTreeWidget):
 
-    def __init__(self, storage, show_files):
+    def __init__(self, storage, show_files=False, item_func=browser_item):
         QTreeWidget.__init__(self)
+        self.item_func = item_func
         self.show_files = show_files
         self.create_children(storage, self)
         self.name = storage.name
         self.object_id = storage.persistent_id
         self.setMinimumHeight(350)
         self.setHeaderHidden(True)
+        self.storage = storage
 
     def create_children(self, f, parent):
         for child in sorted(f.folders, key=attrgetter('name')):
-            i = item(child, parent)
+            i = self.item_func(child, parent)
             self.create_children(child, i)
         if self.show_files:
             for child in sorted(f.files, key=attrgetter('name')):
-                i = item(child, parent)
+                i = self.item_func(child, parent)
 
     @property
     def current_item(self):
@@ -96,14 +97,14 @@ class Browser(QDialog):
     def current_item(self):
         return self.folders.current_item
 
-class TopLevel(QDialog):
+class IgnoredFolders(QDialog):
 
     def __init__(self, dev, ignored_folders=None, parent=None):
         QDialog.__init__(self, parent)
         self.l = l = QVBoxLayout()
         self.setLayout(l)
         self.la = la = QLabel('<p>'+ _('<b>Scanned folders:</b>') + ' ' +
-            _('You can select which top level folders calibre will '
+            _('You can select which folders calibre will '
               'scan when searching this device for books.'))
         la.setWordWrap(True)
         l.addWidget(la)
@@ -112,17 +113,18 @@ class TopLevel(QDialog):
         self.widgets = []
 
         for storage in dev.filesystem_cache.entries:
-            w = QListWidget(self)
-            w.storage = storage
+            self.dev = dev
+            w = Storage(storage, item_func=self.create_item)
+            del self.dev
             self.tabs.addTab(w, storage.name)
             self.widgets.append(w)
-            for child in sorted(storage.folders, key=attrgetter('name')):
-                i = QListWidgetItem(child.name)
-                i.setFlags(Qt.ItemIsUserCheckable | Qt.ItemIsEnabled)
-                i.setCheckState(Qt.Unchecked if
-                    dev.is_folder_ignored(storage, child.name,
-                            ignored_folders=ignored_folders) else Qt.Checked)
-                w.addItem(i)
+            w.itemChanged.connect(self.item_changed)
+
+        self.la2 = la = QLabel(_(
+            'If you a select a previously unselected folder, any sub-folders'
+            ' will not be visible until you restart calibre.'))
+        l.addWidget(la)
+        la.setWordWrap(True)
 
         self.bb = QDialogButtonBox(QDialogButtonBox.Ok |
                                    QDialogButtonBox.Cancel)
@@ -136,29 +138,68 @@ class TopLevel(QDialog):
         self.setWindowTitle(_('Choose folders to scan'))
         self.setWindowIcon(QIcon(I('devices/tablet.png')))
 
-        self.resize(500, 500)
+        self.resize(600, 500)
+
+    def item_changed(self, item, column):
+        w = item.treeWidget()
+        root = w.invisibleRootItem()
+        w.itemChanged.disconnect(self.item_changed)
+        try:
+            if item.checkState(0) == Qt.Checked:
+                # Ensure that the parents of this item are checked
+                p = item.parent()
+                while p is not None and p is not root:
+                    p.setCheckState(0, Qt.Checked)
+                    p = p.parent()
+            # Set the state of all descendants to the same state as this item
+            for child in self.iterchildren(item):
+                child.setCheckState(0, item.checkState(0))
+        finally:
+            w.itemChanged.connect(self.item_changed)
+
+    def iterchildren(self, node):
+        ' Iterate over all descendants of node '
+        for i in xrange(node.childCount()):
+            child = node.child(i)
+            yield child
+            for gc in self.iterchildren(child):
+                yield gc
+
+    def create_item(self, f, parent):
+        name = f.name
+        ans = QTreeWidgetItem(parent, [name])
+        ans.setData(0, Qt.UserRole, '/'.join(f.full_path[1:]))
+        ans.setFlags(Qt.ItemIsUserCheckable | Qt.ItemIsEnabled)
+        ans.setCheckState(0,
+            Qt.Unchecked if self.dev.is_folder_ignored(f.storage_id, f.full_path[1:]) else Qt.Checked)
+        ans.setData(0, Qt.DecorationRole, file_icon_provider().icon_from_ext('dir'))
+        return ans
 
     def select_all(self):
         w = self.tabs.currentWidget()
-        for i in xrange(w.count()):
-            x = w.item(i)
-            x.setCheckState(Qt.Checked)
+        for i in xrange(w.invisibleRootItem().childCount()):
+            c = w.invisibleRootItem().child(i)
+            c.setCheckState(0, Qt.Checked)
 
     def select_none(self):
         w = self.tabs.currentWidget()
-        for i in xrange(w.count()):
-            x = w.item(i)
-            x.setCheckState(Qt.Unchecked)
+        for i in xrange(w.invisibleRootItem().childCount()):
+            c = w.invisibleRootItem().child(i)
+            c.setCheckState(0, Qt.Unchecked)
 
     @property
     def ignored_folders(self):
         ans = {}
         for w in self.widgets:
-            ans[unicode(w.storage.object_id)] = folders = []
-            for i in xrange(w.count()):
-                x = w.item(i)
-                if x.checkState() != Qt.Checked:
-                    folders.append(unicode(x.text()))
+            folders = set()
+            for node in self.iterchildren(w.invisibleRootItem()):
+                if node.checkState(0) == Qt.Checked:
+                    continue
+                path = unicode(node.data(0, Qt.UserRole).toString())
+                parent = path.rpartition('/')[0]
+                if '/' not in path or icu_lower(parent) not in folders:
+                    folders.add(icu_lower(path))
+            ans[unicode(w.storage.storage_id)] = list(folders)
         return ans
 
 def setup_device():
@@ -184,17 +225,17 @@ def browse():
     dev.shutdown()
     return d.current_item
 
-def top_level():
+def ignored_folders():
     from calibre.gui2 import Application
     app = Application([])
     app
     dev = setup_device()
-    d = TopLevel(dev, None)
+    d = IgnoredFolders(dev)
     d.exec_()
     dev.shutdown()
     return d.ignored_folders
 
 if __name__ == '__main__':
-    # print (browse())
-    print ('Ignored:', top_level())
+    print (browse())
+    # print ('Ignored:', ignored_folders())
 
