@@ -440,7 +440,7 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
             if (f in ['author_sort'] or
                     (fm[f]['datatype'] in ['text', 'series', 'enumeration', 'comments']
                      and fm[f].get('search_terms', None)
-                     and f not in ['formats', 'ondevice']) or
+                     and f not in ['formats', 'ondevice', 'series_sort']) or
                     (fm[f]['datatype'] in ['int', 'float', 'bool', 'datetime'] and
                      f not in ['id', 'timestamp'])):
                 self.all_fields.append(f)
@@ -794,10 +794,13 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
         flags |= re.UNICODE
 
         try:
+            stext = unicode(self.search_for.text())
+            if not stext:
+                raise Exception(_('You must specify a search expression in the "Search for" field'))
             if self.search_mode.currentIndex() == 0:
-                self.s_r_obj = re.compile(re.escape(unicode(self.search_for.text())), flags)
+                self.s_r_obj = re.compile(re.escape(stext), flags)
             else:
-                self.s_r_obj = re.compile(unicode(self.search_for.text()), flags)
+                self.s_r_obj = re.compile(stext, flags)
         except Exception as e:
             self.s_r_obj = None
             self.s_r_error = e
