@@ -133,10 +133,10 @@ class TagListEditor(QDialog, Ui_TagListEditor):
                 select_item = item
             item = CountTableWidgetItem(self.counts[tag])
             # only the name column can be selected
-            item.setFlags (item.flags() & ~Qt.ItemIsSelectable)
+            item.setFlags (item.flags() & ~(Qt.ItemIsSelectable|Qt.ItemIsEditable))
             self.table.setItem(row, 1, item)
             item = QTableWidgetItem('')
-            item.setFlags (item.flags() & ~Qt.ItemIsSelectable)
+            item.setFlags (item.flags() & ~(Qt.ItemIsSelectable|Qt.ItemIsEditable))
             self.table.setItem(row, 2, item)
 
         # Scroll to the selected item if there is one
