@@ -10,7 +10,7 @@ from PyQt4.Qt import QApplication
 from calibre.gui2.preferences import ConfigWidgetBase, test_widget, \
         CommaSeparatedList
 from calibre.gui2.preferences.search_ui import Ui_Form
-from calibre.gui2 import config, error_dialog
+from calibre.gui2 import config, error_dialog, gprefs
 from calibre.utils.config import prefs
 from calibre.utils.icu import sort_key
 from calibre.library.caches import set_use_primary_find_in_search
@@ -26,6 +26,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
 
         r('search_as_you_type', config)
         r('highlight_search_matches', config)
+        r('show_highlight_toggle_button', gprefs)
         r('limit_search_columns', prefs)
         r('use_primary_find_in_search', prefs)
         r('limit_search_columns_to', prefs, setting=CommaSeparatedList)
