@@ -6,14 +6,13 @@ __license__ = 'GPL 3'
 __copyright__ = '2011, John Schember <john@nachtimwald.com>'
 __docformat__ = 'restructuredtext en'
 
-import mimetypes
 from contextlib import closing
 
 from lxml import etree
 
 from PyQt4.Qt import QUrl
 
-from calibre import browser
+from calibre import (browser, guess_extension)
 from calibre.gui2 import open_url
 from calibre.gui2.store import StorePlugin
 from calibre.gui2.store.search_result import SearchResult
@@ -29,7 +28,7 @@ class OpenSearchOPDSStore(StorePlugin):
     def open(self, parent=None, detail_item=None, external=False):
         if not hasattr(self, 'web_url'):
             return
-        
+
         if external or self.config.get('open_external', False):
             open_url(QUrl(detail_item if detail_item else self.web_url))
         else:
@@ -52,7 +51,7 @@ class OpenSearchOPDSStore(StorePlugin):
         oquery.searchTerms = query
         oquery.count = max_results
         url = oquery.url()
-        
+
         counter = max_results
         br = browser()
         with closing(br.open(url, timeout=timeout)) as f:
@@ -60,18 +59,18 @@ class OpenSearchOPDSStore(StorePlugin):
             for data in doc.xpath('//*[local-name() = "entry"]'):
                 if counter <= 0:
                     break
-            
+
                 counter -= 1
-    
+
                 s = SearchResult()
-                
+
                 s.detail_item = ''.join(data.xpath('./*[local-name() = "id"]/text()')).strip()
 
                 for link in data.xpath('./*[local-name() = "link"]'):
                     rel = link.get('rel')
                     href = link.get('href')
                     type = link.get('type')
-                    
+
                     if rel and href and type:
                         if 'http://opds-spec.org/thumbnail' in rel:
                             s.cover_url = href
@@ -81,15 +80,15 @@ class OpenSearchOPDSStore(StorePlugin):
                             s.detail_item = href
                         elif 'http://opds-spec.org/acquisition' in rel:
                             if type:
-                                ext = mimetypes.guess_extension(type)
+                                ext = guess_extension(type)
                                 if ext:
                                     ext = ext[1:].upper().strip()
                                     s.downloads[ext] = href
                 s.formats = ', '.join(s.downloads.keys()).strip()
-                
+
                 s.title = ' '.join(data.xpath('./*[local-name() = "title"]//text()')).strip()
                 s.author = ', '.join(data.xpath('./*[local-name() = "author"]//*[local-name() = "name"]//text()')).strip()
-                
+
                 price_e = data.xpath('.//*[local-name() = "price"][1]')
                 if price_e:
                     price_e = price_e[0]
@@ -97,6 +96,6 @@ class OpenSearchOPDSStore(StorePlugin):
                     price = ''.join(price_e.xpath('.//text()')).strip()
                     s.price = currency_code + ' ' + price
                     s.price = s.price.strip()
-                
+
 
                 yield s
