@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import (unicode_literals, division, absolute_import, print_function)
-store_version = 1 # Needed for dynamic plugin loading
+store_version = 2 # Needed for dynamic plugin loading
 
 __license__ = 'GPL 3'
 __copyright__ = '2011, John Schember <john@nachtimwald.com>'
@@ -44,7 +44,7 @@ class BNStore(BasicStoreConfig, StorePlugin):
         with closing(br.open(url, timeout=timeout)) as f:
             raw = f.read()
             doc = html.fromstring(raw)
-            for data in doc.xpath('//ul[contains(@class, "result-set")]/li[contains(@class, "result")]'):
+            for data in doc.xpath('//ol[contains(@class, "result-set")]/li[contains(@class, "result")]'):
                 if counter <= 0:
                     break
 
