@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import (unicode_literals, division, absolute_import, print_function)
-store_version = 1 # Needed for dynamic plugin loading
+store_version = 2 # Needed for dynamic plugin loading
 
 __license__ = 'GPL 3'
 __copyright__ = '2011, John Schember <john@nachtimwald.com>'
@@ -53,7 +53,7 @@ class LibreDEStore(BasicStoreConfig, StorePlugin):
                 if counter <= 0:
                     break
 
-                details = data.xpath('./div[@class="articleinfobox"]')
+                details = data.xpath('./div[contains(@class, "articleinfobox")]')
                 if not details:
                     continue
                 details = details[0]
