@@ -6,7 +6,7 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2014, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import sys, os
+import sys, os, re
 from functools import partial
 
 from PyQt4.Qt import (
@@ -93,6 +93,7 @@ def changed_files(list_of_names1, list_of_names2, get_data1, get_data2):
         added_names.add(name)
     return cache, changed_names, renamed_names, removed_names, added_names
 
+
 def get_decoded_raw(name):
     from calibre.ebooks.chardet import xml_to_unicode, force_encoding
     with open(name, 'rb') as f:
@@ -107,7 +108,11 @@ def get_decoded_raw(name):
         if syntax in {'html', 'xml'}:
             raw = xml_to_unicode(raw, verbose=True)[0]
         else:
-            enc = force_encoding(raw, verbose=True)
+            m = re.search(r"coding[:=]\s*([-\w.]+)", raw[:1024], flags=re.I)
+            if m is not None:
+                enc = m.group(1)
+            else:
+                enc = force_encoding(raw, verbose=True)
             try:
                 raw = raw.decode(enc)
             except ValueError:
@@ -180,13 +185,15 @@ class Diff(Dialog):
     revert_requested = pyqtSignal()
     line_activated = pyqtSignal(object, object, object)
 
-    def __init__(self, revert_button_msg=None, parent=None, show_open_in_editor=False):
+    def __init__(self, revert_button_msg=None, parent=None, show_open_in_editor=False, show_as_window=False):
         self.context = 3
         self.beautify = False
         self.apply_diff_calls = []
         self.show_open_in_editor = show_open_in_editor
         self.revert_button_msg = revert_button_msg
         Dialog.__init__(self, _('Differences between books'), 'diff-dialog', parent=parent)
+        if show_as_window:
+            self.setWindowFlags(Qt.Window)
         self.view.line_activated.connect(self.line_activated)
 
     def sizeHint(self):
@@ -257,7 +264,8 @@ class Diff(Dialog):
         for i in (3, 5, 10, 50):
             cm.addAction(_('Show %d lines of context') % i, partial(self.change_context, i))
         cm.addAction(_('Show all text'), partial(self.change_context, None))
-        m.addAction(_('Beautify files before comparing them'), partial(self.change_beautify, True))
+        self.beautify_action = m.addAction('', self.toggle_beautify)
+        self.set_beautify_action_text()
         m.addMenu(cm)
         l.addWidget(b, r, 7)
 
@@ -268,9 +276,10 @@ class Diff(Dialog):
 
         self.bb.setStandardButtons(self.bb.Close)
         if self.revert_button_msg is not None:
-            self.rvb = b = self.bb.addButton(self.revert_button_msg, self.bb.RejectRole)
-            b.setIcon(QIcon(I('edit-undo.png')))
+            self.rvb = b = self.bb.addButton(self.revert_button_msg, self.bb.ActionRole)
+            b.setIcon(QIcon(I('edit-undo.png'))), b.setAutoDefault(False)
             b.clicked.connect(self.revert_requested)
+            b.clicked.connect(self.reject)
         self.bb.button(self.bb.Close).setDefault(True)
         self.hl.addWidget(self.bb, r)
 
@@ -306,12 +315,16 @@ class Diff(Dialog):
                 self.view.add_diff(*args, **kwargs)
             self.view.finalize()
 
-    def change_beautify(self, beautify):
-        if beautify == self.beautify:
-            return
-        self.beautify = beautify
+    def toggle_beautify(self):
+        self.beautify = not self.beautify
+        self.set_beautify_action_text()
         self.refresh()
 
+    def set_beautify_action_text(self):
+        self.beautify_action.setText(
+            _('Beautify files before comparing them') if not self.beautify else
+            _('Do not beautify files before comparing'))
+
     def __enter__(self):
         self.stacks.setCurrentIndex(0)
         self.busy.pi.startAnimation()
@@ -434,10 +447,10 @@ def main(args=sys.argv):
     else:
         attr = 'file_diff'
     app = QApplication([])
-    d = Diff()
+    d = Diff(show_as_window=True)
     d.show()
     getattr(d, attr)(left, right)
-    app.exec_()
+    return app.exec_()
 
 if __name__ == '__main__':
     main()
