@@ -16,7 +16,7 @@ from future_builtins import zip
 
 import regex
 from PyQt4.Qt import (
-    QSplitter, QApplication, QPlainTextDocumentLayout, QTextDocument, QTimer,
+    QSplitter, QApplication, QTimer,
     QTextCursor, QTextCharFormat, Qt, QRect, QPainter, QPalette, QPen, QBrush,
     QColor, QTextLayout, QCursor, QFont, QSplitterHandle, QPainterPath,
     QHBoxLayout, QWidget, QScrollBar, QEventLoop, pyqtSignal, QImage, QPixmap,
@@ -25,9 +25,10 @@ from PyQt4.Qt import (
 from calibre import human_readable, fit_image
 from calibre.gui2 import info_dialog
 from calibre.gui2.tweak_book import tprefs
-from calibre.gui2.tweak_book.editor.text import PlainTextEdit, get_highlighter, default_font_family, LineNumbers
-from calibre.gui2.tweak_book.editor.themes import THEMES, default_theme, theme_color
+from calibre.gui2.tweak_book.editor.text import PlainTextEdit, default_font_family, LineNumbers
+from calibre.gui2.tweak_book.editor.themes import theme_color
 from calibre.gui2.tweak_book.diff import get_sequence_matcher
+from calibre.gui2.tweak_book.diff.highlight import get_theme, get_highlighter
 
 Change = namedtuple('Change', 'ltop lbot rtop rbot kind')
 
@@ -39,12 +40,6 @@ class BusyCursor(object):
     def __exit__(self, *args):
         QApplication.restoreOverrideCursor()
 
-def get_theme():
-    theme = THEMES.get(tprefs['editor_theme'], None)
-    if theme is None:
-        theme = THEMES[default_theme()]
-    return theme
-
 def beautify_text(raw, syntax):
     from lxml import etree
     from calibre.ebooks.oeb.polish.parsing import parse
@@ -165,7 +160,7 @@ class TextBrowser(PlainTextEdit):  # {{{
     def show_context_menu(self, pos):
         m = QMenu(self)
         a = m.addAction
-        i = unicode(self.textCursor().selectedText())
+        i = unicode(self.textCursor().selectedText()).rstrip('\0')
         if i:
             a(QIcon(I('edit-copy.png')), _('Copy to clipboard'), self.copy).setShortcut(QKeySequence.Copy)
 
@@ -198,8 +193,9 @@ class TextBrowser(PlainTextEdit):  # {{{
         for i, (num, text) in enumerate(self.headers):
             if num > block_number:
                 name = text if i == 0 else self.headers[i - 1][1]
+                break
         else:
-            name = self.headers[0][1]
+            name = self.headers[-1][1]
         self.line_activated.emit(name, lnum, bool(self.right))
 
     def search(self, query, reverse=False):
@@ -392,38 +388,6 @@ class TextBrowser(PlainTextEdit):  # {{{
 
 # }}}
 
-class Highlight(QTextDocument):  # {{{
-
-    def __init__(self, parent, text, syntax):
-        QTextDocument.__init__(self, parent)
-        self.l = QPlainTextDocumentLayout(self)
-        self.setDocumentLayout(self.l)
-        self.highlighter = get_highlighter(syntax)(self)
-        self.highlighter.apply_theme(get_theme())
-        self.highlighter.setDocument(self)
-        self.setPlainText(text)
-
-    def copy_lines(self, lo, hi, cursor):
-        ''' Copy specified lines from the syntax highlighted buffer into the
-        destination cursor, preserving all formatting created by the syntax
-        highlighter. '''
-        num = hi - lo
-        if num > 0:
-            block = self.findBlockByNumber(lo)
-            while num > 0:
-                num -= 1
-                cursor.insertText(block.text())
-                dest_block = cursor.block()
-                c = QTextCursor(dest_block)
-                for af in block.layout().additionalFormats():
-                    start = dest_block.position() + af.start
-                    c.setPosition(start), c.setPosition(start + af.length, c.KeepAnchor)
-                    c.setCharFormat(af.format)
-                cursor.insertBlock()
-                cursor.setCharFormat(QTextCharFormat())
-                block = block.next()
-# }}}
-
 class DiffSplitHandle(QSplitterHandle):  # {{{
 
     WIDTH = 30  # px
@@ -692,12 +656,19 @@ class DiffSplit(QSplitter):  # {{{
         right_text = unicodedata.normalize('NFC', right_text)
         if beautify and syntax in {'xml', 'html', 'css'}:
             left_text, right_text = beautify_text(left_text, syntax), beautify_text(right_text, syntax)
+            if len(left_text) == len(right_text) and left_text == right_text:
+                for v in (self.left, self.right):
+                    c = v.textCursor()
+                    c.movePosition(c.End)
+                    c.insertText('[%s]\n\n' % _('The files are identical after beautifying'))
+                return
+
         left_lines = self.left_lines = left_text.splitlines()
         right_lines = self.right_lines = right_text.splitlines()
 
         cruncher = get_sequence_matcher()(None, left_lines, right_lines)
 
-        left_highlight, right_highlight = Highlight(self, left_text, syntax), Highlight(self, right_text, syntax)
+        left_highlight, right_highlight = get_highlighter(self.left, left_text, syntax), get_highlighter(self.right, right_text, syntax)
         cl, cr = self.left_cursor, self.right_cursor = self.left.textCursor(), self.right.textCursor()
         cl.beginEditBlock(), cr.beginEditBlock()
         cl.movePosition(cl.End), cr.movePosition(cr.End)
@@ -718,6 +689,7 @@ class DiffSplit(QSplitter):  # {{{
                 self.left.line_number_map[self.changes[-1].ltop] = '-'
                 self.right.line_number_map[self.changes[-1].rtop] = '-'
 
+            ahi = bhi = 0
             for i, group in enumerate(cruncher.get_grouped_opcodes(context)):
                 for j, (tag, alo, ahi, blo, bhi) in enumerate(group):
                     if j == 0 and (i > 0 or min(alo, blo) > 0):
@@ -778,11 +750,29 @@ class DiffSplit(QSplitter):  # {{{
         self.changes.append(Change(
             rtop=start_block, rbot=current_block, ltop=l, lbot=l, kind='insert'))
 
+    def trim_identical_leading_lines(self, alo, ahi, blo, bhi):
+        ''' The patience diff algorithm sometimes results in a block of replace
+        lines with identical leading lines. Remove these. This can cause extra
+        lines of context, but that is better than having extra lines of diff
+        with no actual changes. '''
+        a, b = self.left_lines, self.right_lines
+        leading = 0
+        while alo < ahi and blo < bhi and a[alo] == b[blo]:
+            leading += 1
+            alo += 1
+            blo += 1
+        if leading > 0:
+            self.equal(alo - leading, alo, blo - leading, blo)
+        return alo, ahi, blo, bhi
+
     def replace(self, alo, ahi, blo, bhi):
         ''' When replacing one block of lines with another, search the blocks
         for *similar* lines; the best-matching pair (if any) is used as a synch
         point, and intraline difference marking is done on the similar pair.
         Lots of work, but often worth it.  '''
+        alo, ahi, blo, bhi = self.trim_identical_leading_lines(alo, ahi, blo, bhi)
+        if alo == ahi and blo == bhi:
+            return
         if ahi + bhi - alo - blo > 100:
             # Too many lines, this will be too slow
             # http://bugs.python.org/issue6931
@@ -968,7 +958,7 @@ class DiffView(QWidget):  # {{{
         changes = self.changes[which]
         bar = self.bars[which]
         syncpos = self.syncpos + bar.value()
-        prev = (0, 0, None)
+        prev = 0
         for i, (top, bot, kind) in enumerate(changes):
             if syncpos <= bot:
                 if top <= syncpos:
@@ -979,15 +969,14 @@ class DiffView(QWidget):  # {{{
                         ratio = 0
                     return 'in', i, ratio
                 else:
-                    # syncpos is after the change
-                    offset = syncpos - prev[1]
+                    # syncpos is after the previous change
+                    offset = syncpos - prev
                     return 'after', i - 1, offset
-                break
             else:
-                prev = (top, bot, kind)
-        else:
-            offset = syncpos - prev[1]
-            return 'after', len(self.changes) - 1, offset
+                # syncpos is after the current change
+                prev = bot
+        offset = syncpos - prev
+        return 'after', len(changes) - 1, offset
 
     def scroll_to(self, which, position):
         changes = self.changes[which]
