@@ -6,7 +6,7 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import sys, string, weakref
+import sys, weakref
 from functools import wraps
 
 from PyQt4.Qt import (
@@ -16,6 +16,9 @@ from PyQt4.Qt import (
 from calibre import fit_image
 from calibre.constants import isosx
 from calibre.gui2 import error_dialog, pixmap_to_data
+from calibre.gui2.dnd import (
+    IMAGE_EXTENSIONS, dnd_has_extension, dnd_has_image, dnd_get_image, DownloadDialog)
+from calibre.gui2.tweak_book import capitalize
 from calibre.utils.config_base import tweaks
 from calibre.utils.magick import Image
 from calibre.utils.magick.draw import identify_data
@@ -30,10 +33,6 @@ def painter(func):
             painter.restore()
     return ans
 
-ucase_map = {l:string.ascii_uppercase[i] for i, l in enumerate(string.ascii_lowercase)}
-def capitalize(x):
-    return ucase_map[x[0]] + x[1:]
-
 class SelectionState(object):
 
     __slots__ = ('last_press_point', 'current_mode', 'rect', 'in_selection', 'drag_corner', 'dragging', 'last_drag_pos')
@@ -214,7 +213,8 @@ class Replace(Command):
 
     def __init__(self, img, text, canvas):
         self.after_image = img
-        Command.__init__(self, text, canvas)
+        self.TEXT = text
+        Command.__init__(self, canvas)
 
     def __call__(self, canvas):
         if canvas.has_selection and canvas.selection_state.rect is not None:
@@ -259,8 +259,44 @@ class Canvas(QWidget):
     def is_modified(self):
         return self.current_image is not self.original_image
 
+    # Drag 'n drop {{{
+    DROPABBLE_EXTENSIONS = IMAGE_EXTENSIONS
+
+    def dragEnterEvent(self, event):
+        md = event.mimeData()
+        if dnd_has_extension(md, self.DROPABBLE_EXTENSIONS) or dnd_has_image(md):
+            event.acceptProposedAction()
+
+    def dropEvent(self, event):
+        event.setDropAction(Qt.CopyAction)
+        md = event.mimeData()
+
+        x, y = dnd_get_image(md)
+        if x is not None:
+            # We have an image, set cover
+            event.accept()
+            if y is None:
+                # Local image
+                self.undo_stack.push(Replace(x.toImage(), _('Drop image'), self))
+            else:
+                d = DownloadDialog(x, y, self.gui)
+                d.start_download()
+                if d.err is None:
+                    with open(d.fpath, 'rb') as f:
+                        img = QImage()
+                        img.loadFromData(f.read())
+                    if not img.isNull():
+                        self.undo_stack.push(Replace(img, _('Drop image'), self))
+
+        event.accept()
+
+    def dragMoveEvent(self, event):
+        event.acceptProposedAction()
+    # }}}
+
     def __init__(self, parent=None):
         QWidget.__init__(self, parent)
+        self.setAcceptDrops(True)
         self.setMouseTracking(True)
         self.setFocusPolicy(Qt.ClickFocus)
         self.selection_state = SelectionState()
