@@ -8,8 +8,9 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import re
 from functools import partial
+from collections import namedtuple
 
-from PyQt4.Qt import QFont
+from PyQt4.Qt import QFont, QTextBlockUserData
 
 from calibre.gui2.tweak_book.editor import SyntaxTextCharFormat
 from calibre.gui2.tweak_book.editor.syntax.base import SyntaxHighlighter, run_loop
@@ -20,7 +21,7 @@ from html5lib.constants import cdataElements, rcdataElements
 cdata_tags = cdataElements | rcdataElements
 bold_tags = {'b', 'strong'} | {'h%d' % d for d in range(1, 7)}
 italic_tags = {'i', 'em'}
-normal_pat = re.compile(r'[^<>&]')
+normal_pat = re.compile(r'[^<>&]+')
 entity_pat = re.compile(r'&#{0,1}[a-zA-Z0-9]{1,8};')
 tag_name_pat = re.compile(r'/{0,1}[a-zA-Z0-9:]+')
 space_chars = ' \t\r\n\u000c'
@@ -76,6 +77,17 @@ class State(object):
         self.parse = self.bold = self.italic = self.css = 0
         self.tag = self.UNKNOWN_TAG
 
+TagStart = namedtuple('TagStart', 'offset prefix name closing is_start')
+TagEnd = namedtuple('TagEnd', 'offset self_closing is_start')
+
+def add_tag_data(state, tag):
+    ud = q = state.get_user_data()
+    if ud is None:
+        ud = HTMLUserData()
+    ud.tags.append(tag)
+    if q is None:
+        state.set_user_data(ud)
+
 def css(state, text, i, formats):
     ' Inside a <style> tag '
     pat = cdata_close_pats['style']
@@ -92,6 +104,7 @@ def css(state, text, i, formats):
     if m is not None:
         state.clear()
         state.parse = State.IN_CLOSING_TAG
+        add_tag_data(state, TagStart(m.start(), 'style', '', True, True))
         ans.extend([(2, formats['end_tag']), (len(m.group()) - 2, formats['tag_name'])])
     return ans
 
@@ -104,6 +117,7 @@ def cdata(state, text, i, formats):
         return [(len(text) - i, fmt)]
     state.parse = State.IN_CLOSING_TAG
     num = m.start() - i
+    add_tag_data(state, TagStart(m.start(), state.tag, '', True, True))
     return [(num, fmt), (2, formats['end_tag']), (len(m.group()) - 2, formats['tag_name'])]
 
 def mark_nbsp(state, text, nbsp_format):
@@ -118,10 +132,16 @@ def mark_nbsp(state, text, nbsp_format):
     last = 0
     for m in nbsp_pat.finditer(text):
         ans.extend([(m.start() - last, fmt), (m.end() - m.start(), nbsp_format)])
+        last = m.end()
     if not ans:
         ans = [(len(text), fmt)]
     return ans
 
+class HTMLUserData(QTextBlockUserData):
+
+    def __init__(self):
+        QTextBlockUserData.__init__(self)
+        self.tags = []
 
 def normal(state, text, i, formats):
     ' The normal state in between tags '
@@ -154,6 +174,7 @@ def normal(state, text, i, formats):
         if prefix and name:
             ans.append((len(prefix)+1, formats['nsprefix']))
         ans.append((len(name or prefix), formats['tag_name']))
+        add_tag_data(state, TagStart(i, prefix, name, closing, True))
         return ans
 
     if ch == '&':
@@ -179,7 +200,9 @@ def opening_tag(cdata_tags, state, text, i, formats):
             return [(1, formats['/'])]
         state.parse = state.NORMAL
         state.tag = State.UNKNOWN_TAG
-        return [(len(m.group()), formats['tag'])]
+        l = len(m.group())
+        add_tag_data(state, TagEnd(i + l - 1, True, False))
+        return [(l, formats['tag'])]
     if ch == '>':
         state.parse = state.NORMAL
         tag = state.tag.lower()
@@ -190,6 +213,7 @@ def opening_tag(cdata_tags, state, text, i, formats):
                 state.parse = state.CSS
         state.bold += int(tag in bold_tags)
         state.italic += int(tag in italic_tags)
+        add_tag_data(state, TagEnd(i, False, False))
         return [(1, formats['tag'])]
     m = attribute_name_pat.match(text, i)
     if m is None:
@@ -256,6 +280,7 @@ def closing_tag(state, text, i, formats):
     if num > 1:
         ans.insert(0, (num - 1, formats['bad-closing']))
     state.tag = State.UNKNOWN_TAG
+    add_tag_data(state, TagEnd(pos, False, False))
     return ans
 
 def in_comment(state, text, i, formats):
