@@ -13,17 +13,19 @@ from functools import partial
 
 import sip
 from PyQt4.Qt import (
-    QWidget, QTreeWidget, QGridLayout, QSize, Qt, QTreeWidgetItem, QIcon,
+    QWidget, QTreeWidget, QGridLayout, QSize, Qt, QTreeWidgetItem, QIcon, QFont,
     QStyledItemDelegate, QStyle, QPixmap, QPainter, pyqtSignal, QMenu, QTimer,
-    QDialogButtonBox, QDialog, QLabel, QLineEdit, QVBoxLayout, QScrollArea, QRadioButton)
+    QDialogButtonBox, QDialog, QLabel, QLineEdit, QVBoxLayout, QScrollArea,
+    QRadioButton, QFormLayout, QSpinBox, QListWidget, QListWidgetItem, QCheckBox)
 
-from calibre import human_readable, sanitize_file_name_unicode
+from calibre import human_readable, sanitize_file_name_unicode, plugins
 from calibre.ebooks.oeb.base import OEB_STYLES, OEB_DOCS
 from calibre.ebooks.oeb.polish.container import guess_type, OEB_FONTS
+from calibre.ebooks.oeb.polish.replace import get_recommended_folders
 from calibre.ebooks.oeb.polish.cover import (
     get_cover_page_name, get_raster_cover_name, is_raster_image)
 from calibre.gui2 import error_dialog, choose_files, question_dialog, elided_text, choose_save_file
-from calibre.gui2.tweak_book import current_container
+from calibre.gui2.tweak_book import current_container, tprefs
 from calibre.gui2.tweak_book.editor import syntax_from_mime
 from calibre.gui2.tweak_book.templates import template_for
 from calibre.utils.icu import sort_key
@@ -35,6 +37,51 @@ LINEAR_ROLE = CATEGORY_ROLE + 1
 MIME_ROLE = LINEAR_ROLE + 1
 NBSP = '\xa0'
 
+def name_is_ok(name, show_error):
+    if not name or not name.strip():
+        return show_error('') and False
+    ext = name.rpartition('.')[-1]
+    if not ext or ext == name:
+        return show_error(_('The file name must have an extension')) and False
+    norm = name.replace('\\', '/')
+    parts = name.split('/')
+    for x in parts:
+        if sanitize_file_name_unicode(x) != x:
+            return show_error(_('The file name contains invalid characters')) and False
+    if current_container().has_name(norm):
+        return show_error(_('This file name already exists in the book')) and False
+    show_error('')
+    return True
+
+def get_bulk_rename_settings(parent, number, msg=None, sanitize=sanitize_file_name_unicode, leading_zeros=True):  # {{{
+    d = QDialog(parent)
+    d.l = l = QFormLayout(d)
+    d.setLayout(l)
+    d.prefix = p = QLineEdit(d)
+    p.setText(_('Chapter-'))
+    p.selectAll()
+    d.la = la = QLabel(msg or _(
+        'All selected files will be renamed to the form prefix-number'))
+    l.addRow(la)
+    l.addRow(_('&Prefix:'), p)
+    d.num = num = QSpinBox(d)
+    num.setMinimum(0), num.setValue(1), num.setMaximum(1000)
+    l.addRow(_('Starting &number:'), num)
+    d.bb = bb = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
+    bb.accepted.connect(d.accept), bb.rejected.connect(d.reject)
+    l.addRow(bb)
+
+    if d.exec_() == d.Accepted:
+        prefix = sanitize(unicode(d.prefix.text()))
+        num = d.num.value()
+        fmt = '%d'
+        if leading_zeros:
+            largest = num + number - 1
+            fmt = '%0{0}d'.format(len(str(largest)))
+        return prefix + fmt, num
+    return None, None
+# }}}
+
 class ItemDelegate(QStyledItemDelegate):  # {{{
 
     rename_requested = pyqtSignal(object, object)
@@ -97,14 +144,20 @@ class FileList(QTreeWidget):
     delete_requested = pyqtSignal(object, object)
     reorder_spine = pyqtSignal(object)
     rename_requested = pyqtSignal(object, object)
+    bulk_rename_requested = pyqtSignal(object)
     edit_file = pyqtSignal(object, object, object)
     merge_requested = pyqtSignal(object, object, object)
     mark_requested = pyqtSignal(object, object)
     export_requested = pyqtSignal(object, object)
     replace_requested = pyqtSignal(object, object, object, object)
+    link_stylesheets_requested = pyqtSignal(object, object, object)
 
     def __init__(self, parent=None):
         QTreeWidget.__init__(self, parent)
+        pi = plugins['progress_indicator'][0]
+        if hasattr(pi, 'set_no_activate_on_click'):
+            pi.set_no_activate_on_click(self)
+        self.current_edited_name = None
         self.delegate = ItemDelegate(self)
         self.delegate.rename_requested.connect(self.rename_requested)
         self.setTextElideMode(Qt.ElideMiddle)
@@ -137,7 +190,7 @@ class FileList(QTreeWidget):
                 'misc':'mimetypes/dir.png',
                 'images':'view-image.png',
             }.iteritems()}
-        self.itemDoubleClicked.connect(self.item_double_clicked)
+        self.itemActivated.connect(self.item_double_clicked)
 
     def get_state(self):
         s = {'pos':self.verticalScrollBar().value()}
@@ -170,6 +223,29 @@ class FileList(QTreeWidget):
                 if q == name:
                     self.scrollToItem(c)
 
+    def mark_name_as_current(self, name):
+        current = self.item_from_name(name)
+        if current is not None:
+            if self.current_edited_name is not None:
+                ci = self.item_from_name(self.current_edited_name)
+                if ci is not None:
+                    ci.setData(0, Qt.FontRole, None)
+            self.current_edited_name = name
+            self.mark_item_as_current(current)
+
+    def mark_item_as_current(self, item):
+        font = QFont(self.font())
+        font.setItalic(True)
+        font.setBold(True)
+        item.setData(0, Qt.FontRole, font)
+
+    def clear_currently_edited_name(self):
+        if self.current_edited_name:
+            ci = self.item_from_name(self.current_edited_name)
+            if ci is not None:
+                ci.setData(0, Qt.FontRole, None)
+        self.current_edited_name = None
+
     def build(self, container, preserve_state=True):
         if preserve_state:
             state = self.get_state()
@@ -284,26 +360,35 @@ class FileList(QTreeWidget):
             item.setData(0, LINEAR_ROLE, bool(linear))
             item.setData(0, MIME_ROLE, imt)
             set_display_name(name, item)
-            # TODO: Add appropriate tooltips based on the emblems
+            tooltips = []
             emblems = []
             if name in {cover_page_name, cover_image_name}:
                 emblems.append('default_cover.png')
+                tooltips.append(_('This file is the cover %s for this book') % (_('image') if name == cover_image_name else _('page')))
             if name in container.opf_name:
                 emblems.append('metadata.png')
+                tooltips.append(_('This file contains all the metadata and book structure information'))
             if imt == ncx_mime:
                 emblems.append('toc.png')
+                tooltips.append(_('This file contains the metadata table of contents'))
             if name not in manifested_names and name not in ok_to_be_unmanifested:
                 emblems.append('dialog_question.png')
+                tooltips.append(_('This file is not listed in the book manifest'))
             if linear is False:
                 emblems.append('arrow-down.png')
+                tooltips.append(_('This file is marked as non-linear in the spine\nDrag it to the top to make it linear'))
             if linear is None and icat == 'text':
                 # Text item outside spine
                 emblems.append('dialog_warning.png')
+                tooltips.append(_('This file is a text file that is not referenced in the spine'))
             if category == 'text' and name in processed:
                 # Duplicate entry in spine
-                emblems.append('dialog_warning.png')
+                emblems.append('dialog_error.png')
+                tooltips.append(_('This file occurs more than once in the spine'))
 
             render_emblems(item, emblems)
+            if tooltips:
+                item.setData(0, Qt.ToolTipRole, '\n'.join(tooltips))
             return item
 
         for name, linear in container.spine_names:
@@ -325,6 +410,11 @@ class FileList(QTreeWidget):
         if preserve_state:
             self.set_state(state)
 
+        if self.current_edited_name:
+            item = self.item_from_name(self.current_edited_name)
+            if item is not None:
+                self.mark_item_as_current(item)
+
     def show_context_menu(self, point):
         item = self.itemAt(point)
         if item is None or item in set(self.categories.itervalues()):
@@ -333,24 +423,29 @@ class FileList(QTreeWidget):
         sel = self.selectedItems()
         num = len(sel)
         container = current_container()
-        if num > 0:
-            m.addAction(QIcon(I('trash.png')), _('&Delete selected files'), self.request_delete)
-            m.addSeparator()
         ci = self.currentItem()
         if ci is not None:
             cn = unicode(ci.data(0, NAME_ROLE).toString())
             mt = unicode(ci.data(0, MIME_ROLE).toString())
             cat = unicode(ci.data(0, CATEGORY_ROLE).toString())
             n = elided_text(cn.rpartition('/')[-1])
+            m.addAction(QIcon(I('save.png')), _('Export %s') % n, partial(self.export, cn))
+            if cn not in container.names_that_must_not_be_changed and cn not in container.names_that_must_not_be_removed and mt not in OEB_FONTS:
+                m.addAction(_('Replace %s with file...') % n, partial(self.replace, cn))
+            m.addSeparator()
+
             m.addAction(QIcon(I('modified.png')), _('&Rename %s') % n, self.edit_current_item)
             if is_raster_image(mt):
                 m.addAction(QIcon(I('default_cover.png')), _('Mark %s as cover image') % n, partial(self.mark_as_cover, cn))
             elif current_container().SUPPORTS_TITLEPAGES and mt in OEB_DOCS and cat == 'text':
                 m.addAction(QIcon(I('default_cover.png')), _('Mark %s as cover page') % n, partial(self.mark_as_titlepage, cn))
             m.addSeparator()
-            m.addAction(QIcon(I('save.png')), _('Export %s') % n, partial(self.export, cn))
-            if cn not in container.names_that_must_not_be_changed and cn not in container.names_that_must_not_be_removed and mt not in OEB_FONTS:
-                m.addAction(_('Replace %s with file...') % n, partial(self.replace, cn))
+
+        if num > 0:
+            m.addSeparator()
+            if num > 1:
+                m.addAction(QIcon(I('modified.png')), _('&Bulk rename selected files'), self.request_bulk_rename)
+            m.addAction(QIcon(I('trash.png')), _('&Delete the %d selected file(s)') % num, self.request_delete)
             m.addSeparator()
 
         selected_map = defaultdict(list)
@@ -360,6 +455,9 @@ class FileList(QTreeWidget):
         for items in selected_map.itervalues():
             items.sort(key=self.index_of_name)
 
+        if selected_map['text']:
+            m.addAction(QIcon(I('format-text-color.png')), _('Link &stylesheets...'), partial(self.link_stylesheets, selected_map['text']))
+
         if len(selected_map['text']) > 1:
             m.addAction(QIcon(I('merge.png')), _('&Merge selected text files'), partial(self.start_merge, 'text', selected_map['text']))
         if len(selected_map['styles']) > 1:
@@ -405,6 +503,23 @@ class FileList(QTreeWidget):
         else:
             return QTreeWidget.keyPressEvent(self, ev)
 
+    def request_bulk_rename(self):
+        names = {unicode(item.data(0, NAME_ROLE).toString()) for item in self.selectedItems()}
+        bad = names & current_container().names_that_must_not_be_changed
+        if bad:
+            return error_dialog(self, _('Cannot rename'),
+                         _('The file(s) %s cannot be renamed.') % ('<b>%s</b>' % ', '.join(bad)), show=True)
+        names = sorted(names, key=self.index_of_name)
+        fmt, num = get_bulk_rename_settings(self, len(names))
+        if fmt is not None:
+            def change_name(name, num):
+                parts = name.split('/')
+                base, ext = parts[-1].rpartition('.')[0::2]
+                parts[-1] = (fmt % num) + '.' + ext
+                return '/'.join(parts)
+            name_map = {n:change_name(n, num + i) for i, n in enumerate(names)}
+            self.bulk_rename_requested.emit(name_map)
+
     def request_delete(self):
         names = {unicode(item.data(0, NAME_ROLE).toString()) for item in self.selectedItems()}
         bad = names & current_container().names_that_must_not_be_removed
@@ -431,8 +546,18 @@ class FileList(QTreeWidget):
                     if unicode(child.data(0, NAME_ROLE).toString()) in other_removals:
                         removals.append(child)
 
-        for c in removals:
-            c.parent().removeChild(c)
+        # The sorting by index is necessary otherwise Qt crashes with recursive
+        # repaint detected message
+        for c in sorted(removals, key=lambda x:x.parent().indexOfChild(x), reverse=True):
+            sip.delete(c)
+
+        # A bug in the raster paint engine on linux causes a crash if the scrollbar
+        # is at the bottom and the delete happens to cause the scrollbar to
+        # update
+        b = self.verticalScrollBar()
+        if b.value() == b.maximum():
+            b.setValue(b.minimum())
+            QTimer.singleShot(0, lambda : b.setValue(b.maximum()))
 
     def dropEvent(self, event):
         text = self.categories['text']
@@ -521,6 +646,44 @@ class FileList(QTreeWidget):
         nname = nname + '.' + ext.lower()
         self.replace_requested.emit(name, path, nname, force_mt)
 
+    def link_stylesheets(self, names):
+        s = self.categories['styles']
+        sheets = [unicode(s.child(i).data(0, NAME_ROLE).toString()) for i in xrange(s.childCount())]
+        if not sheets:
+            return error_dialog(self, _('No stylesheets'), _(
+                'This book currently has no stylesheets. You must first create a stylesheet'
+                ' before linking it.'), show=True)
+        d = QDialog(self)
+        d.l = l = QVBoxLayout(d)
+        d.setLayout(l)
+        d.setWindowTitle(_('Choose stylesheets'))
+        d.la = la = QLabel(_('Choose the stylesheets to link. Drag and drop to re-arrange'))
+
+        la.setWordWrap(True)
+        l.addWidget(la)
+        d.s = s = QListWidget(d)
+        l.addWidget(s)
+        s.setDragEnabled(True)
+        s.setDropIndicatorShown(True)
+        s.setDragDropMode(self.InternalMove)
+        s.setAutoScroll(True)
+        s.setDefaultDropAction(Qt.MoveAction)
+        for name in sheets:
+            i = QListWidgetItem(name, s)
+            flags = Qt.ItemIsEnabled | Qt.ItemIsUserCheckable | Qt.ItemIsDragEnabled | Qt.ItemIsSelectable
+            i.setFlags(flags)
+            i.setCheckState(Qt.Checked)
+        d.r = r = QCheckBox(_('Remove existing links to stylesheets'))
+        r.setChecked(tprefs['remove_existing_links_when_linking_sheets'])
+        l.addWidget(r)
+        d.bb = bb = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
+        bb.accepted.connect(d.accept), bb.rejected.connect(d.reject)
+        l.addWidget(bb)
+        if d.exec_() == d.Accepted:
+            tprefs['remove_existing_links_when_linking_sheets'] = r.isChecked()
+            sheets = [unicode(s.item(i).text()) for i in xrange(s.count()) if s.item(i).checkState() == Qt.Checked]
+            if sheets:
+                self.link_stylesheets_requested.emit(names, sheets, r.isChecked())
 
 class NewFileDialog(QDialog):  # {{{
 
@@ -529,7 +692,9 @@ class NewFileDialog(QDialog):  # {{{
         self.l = l = QVBoxLayout()
         self.setLayout(l)
         self.la = la = QLabel(_(
-            'Choose a name for the new file'))
+            'Choose a name for the new (blank) file. To place the file in a'
+            ' specific folder in the book, include the folder name, for example: <i>text/chapter1.html'))
+        la.setWordWrap(True)
         self.setWindowTitle(_('Choose file'))
         l.addWidget(la)
         self.name = n = QLineEdit(self)
@@ -544,11 +709,13 @@ class NewFileDialog(QDialog):  # {{{
         bb.rejected.connect(self.reject)
         self.imp_button = b = bb.addButton(_('Import resource file (image/font/etc.)'), bb.ActionRole)
         b.setIcon(QIcon(I('view-image.png')))
+        b.setToolTip(_('Import a file from your computer as a new'
+                       ' file into the book.'))
         b.clicked.connect(self.import_file)
 
         self.ok_button = bb.button(bb.Ok)
 
-        self.file_data = ''
+        self.file_data = b''
         self.using_template = False
 
     def show_error(self, msg):
@@ -562,25 +729,15 @@ class NewFileDialog(QDialog):  # {{{
             with open(path, 'rb') as f:
                 self.file_data = f.read()
             name = os.path.basename(path)
+            fmap = get_recommended_folders(current_container(), (name,))
+            if fmap[name]:
+                name = '/'.join((fmap[name], name))
             self.name.setText(name)
+            self.la.setText(_('Choose a name for the imported file'))
 
     @property
     def name_is_ok(self):
-        name = unicode(self.name.text())
-        if not name or not name.strip():
-            return self.show_error('')
-        ext = name.rpartition('.')[-1]
-        if not ext or ext == name:
-            return self.show_error(_('The file name must have an extension'))
-        norm = name.replace('\\', '/')
-        parts = name.split('/')
-        for x in parts:
-            if sanitize_file_name_unicode(x) != x:
-                return self.show_error(_('The file name contains invalid characters'))
-        if current_container().has_name(norm):
-            return self.show_error(_('This file name already exists in the book'))
-        self.show_error('')
-        return True
+        return name_is_ok(unicode(self.name.text()), self.show_error)
 
     def update_ok(self, *args):
         self.ok_button.setEnabled(self.name_is_ok)
@@ -593,12 +750,13 @@ class NewFileDialog(QDialog):  # {{{
         name, ext = name.rpartition('.')[0::2]
         name = (name + '.' + ext.lower()).replace('\\', '/')
         mt = guess_type(name)
-        if mt in OEB_DOCS:
-            self.file_data = template_for('html').encode('utf-8')
-            self.using_template = True
-        elif mt in OEB_STYLES:
-            self.file_data = template_for('css').encode('utf-8')
-            self.using_template = True
+        if not self.file_data:
+            if mt in OEB_DOCS:
+                self.file_data = template_for('html').encode('utf-8')
+                self.using_template = True
+            elif mt in OEB_STYLES:
+                self.file_data = template_for('css').encode('utf-8')
+                self.using_template = True
         self.file_name = name
         QDialog.accept(self)
 # }}}
@@ -640,26 +798,14 @@ class MergeDialog(QDialog):  # {{{
 
 class FileListWidget(QWidget):
 
-    delete_requested = pyqtSignal(object, object)
-    reorder_spine = pyqtSignal(object)
-    rename_requested = pyqtSignal(object, object)
-    edit_file = pyqtSignal(object, object, object)
-    merge_requested = pyqtSignal(object, object, object)
-    mark_requested = pyqtSignal(object, object)
-    export_requested = pyqtSignal(object, object)
-    replace_requested = pyqtSignal(object, object, object, object)
-
     def __init__(self, parent=None):
         QWidget.__init__(self, parent)
         self.setLayout(QGridLayout(self))
         self.file_list = FileList(self)
         self.layout().addWidget(self.file_list)
         self.layout().setContentsMargins(0, 0, 0, 0)
-        for x in ('delete_requested', 'reorder_spine', 'rename_requested',
-                  'edit_file', 'merge_requested', 'mark_requested',
-                  'export_requested', 'replace_requested'):
-            getattr(self.file_list, x).connect(getattr(self, x))
-        for x in ('delete_done', 'select_name', 'request_edit'):
+        self.forwarded_signals = {k for k, o in vars(self.file_list.__class__).iteritems() if isinstance(o, pyqtSignal) and '_' in k and not hasattr(self, k)}
+        for x in ('delete_done', 'select_name', 'request_edit', 'mark_name_as_current', 'clear_currently_edited_name'):
             setattr(self, x, getattr(self.file_list, x))
 
     def build(self, container, preserve_state=True):
@@ -669,3 +815,8 @@ class FileListWidget(QWidget):
     def searchable_names(self):
         return self.file_list.searchable_names
 
+    def __getattr__(self, name):
+        if name in self.forwarded_signals:
+            return getattr(self.file_list, name)
+        return QWidget.__getattr__(self, name)
+
