@@ -6,24 +6,38 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
+import unicodedata, os
 from functools import partial
+from itertools import product
+from future_builtins import map
 
 from PyQt4.Qt import (
-    QDockWidget, Qt, QLabel, QIcon, QAction, QApplication, QWidget,
-    QVBoxLayout, QStackedWidget, QTabWidget, QImage, QPixmap, pyqtSignal)
+    QDockWidget, Qt, QLabel, QIcon, QAction, QApplication, QWidget, QEvent,
+    QVBoxLayout, QStackedWidget, QTabWidget, QImage, QPixmap, pyqtSignal,
+    QMenu, QHBoxLayout, QTimer, QUrl)
 
-from calibre.constants import __appname__, get_version
-from calibre.gui2 import elided_text
+from calibre.constants import __appname__, get_version, isosx
+from calibre.gui2 import elided_text, open_url
 from calibre.gui2.keyboard import Manager as KeyboardManager
 from calibre.gui2.main_window import MainWindow
-from calibre.gui2.tweak_book import current_container, tprefs, actions
+from calibre.gui2.throbber import ThrobbingButton, create_donate_widget
+from calibre.gui2.tweak_book import current_container, tprefs, actions, capitalize
 from calibre.gui2.tweak_book.file_list import FileListWidget
 from calibre.gui2.tweak_book.job import BlockingJob
 from calibre.gui2.tweak_book.boss import Boss
+from calibre.gui2.tweak_book.undo import CheckpointView
 from calibre.gui2.tweak_book.preview import Preview
 from calibre.gui2.tweak_book.search import SearchPanel
+from calibre.gui2.tweak_book.check import Check
+from calibre.gui2.tweak_book.toc import TOCViewer
+from calibre.gui2.tweak_book.char_select import CharSelect
+from calibre.gui2.tweak_book.editor.widget import register_text_editor_actions
+from calibre.gui2.tweak_book.editor.insert_resource import InsertImage
 
-class Central(QStackedWidget):
+def open_donate():
+    open_url(QUrl('http://calibre-ebook.com/donate'))
+
+class Central(QStackedWidget):  # {{{
 
     ' The central widget, hosts the editors '
 
@@ -61,6 +75,7 @@ class Central(QStackedWidget):
         self.search_panel = SearchPanel(self)
         l.addWidget(self.search_panel)
         self.restore_state()
+        self.editor_tabs.tabBar().installEventFilter(self)
 
     def _close_requested(self, index):
         editor = self.editor_tabs.widget(index)
@@ -105,7 +120,9 @@ class Central(QStackedWidget):
             self.close_requested.emit(ed)
 
     def close_all_but_current_editor(self):
-        ed = self.current_editor
+        self.close_all_but(self.current_editor)
+
+    def close_all_but(self, ed):
         close = []
         if ed is not None:
             for i in xrange(self.editor_tabs.count()):
@@ -133,14 +150,63 @@ class Central(QStackedWidget):
     def pre_fill_search(self, text):
         self.search_panel.pre_fill(text)
 
+    def eventFilter(self, obj, event):
+        base = super(Central, self)
+        if obj is not self.editor_tabs.tabBar() or event.type() != QEvent.MouseButtonPress or event.button() not in (Qt.RightButton, Qt.MidButton):
+            return base.eventFilter(obj, event)
+        index = self.editor_tabs.tabBar().tabAt(event.pos())
+        if index < 0:
+            return base.eventFilter(obj, event)
+        if event.button() == Qt.MidButton:
+            self._close_requested(index)
+        ed = self.editor_tabs.widget(index)
+        if ed is not None:
+            menu = QMenu(self)
+            menu.addAction(actions['close-current-tab'].icon(), _('Close tab'), partial(self.close_requested.emit, ed))
+            menu.addSeparator()
+            menu.addAction(actions['close-all-but-current-tab'].icon(), _('Close other tabs'), partial(self.close_all_but, ed))
+            menu.exec_(self.editor_tabs.tabBar().mapToGlobal(event.pos()))
+
+        return True
+# }}}
+
+class CursorPositionWidget(QWidget):  # {{{
+
+    def __init__(self, parent):
+        QWidget.__init__(self, parent)
+        self.l = QHBoxLayout(self)
+        self.setLayout(self.l)
+        self.la = QLabel('')
+        self.l.addWidget(self.la)
+        self.l.setContentsMargins(0, 0, 0, 0)
+        f = self.la.font()
+        f.setBold(False)
+        self.la.setFont(f)
+
+    def update_position(self, line=None, col=None, character=None):
+        if line is None:
+            self.la.setText('')
+        else:
+            try:
+                name = unicodedata.name(character, None) if character else None
+            except Exception:
+                name = None
+            text = _('Line: {0} : {1}').format(line, col)
+            if not name:
+                name = {'\t':'TAB'}.get(character, None)
+            if name:
+                text = name + ' : ' + text
+            self.la.setText(text)
+# }}}
+
 class Main(MainWindow):
 
-    APP_NAME = _('Tweak Book')
+    APP_NAME = _('Edit Book')
     STATE_VERSION = 0
 
-    def __init__(self, opts):
+    def __init__(self, opts, notify=None):
         MainWindow.__init__(self, opts, disable_automatic_gc=True)
-        self.boss = Boss(self)
+        self.boss = Boss(self, notify=notify)
         self.setWindowTitle(self.APP_NAME)
         self.setWindowIcon(QIcon(I('tweak.png')))
         self.opts = opts
@@ -152,6 +218,10 @@ class Main(MainWindow):
 
         self.central = Central(self)
         self.setCentralWidget(self.central)
+        self.check_book = Check(self)
+        self.toc_view = TOCViewer(self)
+        self.image_browser = InsertImage(self, for_browsing=True)
+        self.insert_char = CharSelect(self)
 
         self.create_actions()
         self.create_toolbars()
@@ -160,7 +230,11 @@ class Main(MainWindow):
 
         self.status_bar = self.statusBar()
         self.status_bar.addPermanentWidget(self.boss.save_manager.status_widget)
-        self.status_bar.addWidget(QLabel(_('{0} {1} created by {2}').format(__appname__, get_version(), 'Kovid Goyal')))
+        self.cursor_position_widget = CursorPositionWidget(self)
+        self.status_bar.addPermanentWidget(self.cursor_position_widget)
+        self.status_bar_default_msg = la = QLabel(_('{0} {1} created by {2}').format(__appname__, get_version(), 'Kovid Goyal'))
+        la.base_template = unicode(la.text())
+        self.status_bar.addWidget(la)
         f = self.status_bar.font()
         f.setBold(True)
         self.status_bar.setFont(f)
@@ -168,9 +242,19 @@ class Main(MainWindow):
         self.boss(self)
         g = QApplication.instance().desktop().availableGeometry(self)
         self.resize(g.width()-50, g.height()-50)
-        self.restore_state()
 
+        self.restore_state()
+        self.apply_settings()
+
+    def apply_settings(self):
         self.keyboard.finalize()
+        self.setDockNestingEnabled(tprefs['nestable_dock_widgets'])
+        for v, h in product(('top', 'bottom'), ('left', 'right')):
+            p = 'dock_%s_%s' % (v, h)
+            pref = tprefs[p] or tprefs.defaults[p]
+            area = getattr(Qt, '%sDockWidgetArea' % capitalize({'vertical':h, 'horizontal':v}[pref]))
+            self.setCorner(getattr(Qt, '%s%sCorner' % tuple(map(capitalize, (v, h)))), area)
+        self.preview.apply_settings()
 
     def show_status_message(self, msg, timeout=5):
         self.status_bar.showMessage(msg, int(timeout*1000))
@@ -186,7 +270,9 @@ class Main(MainWindow):
         group = _('Global Actions')
 
         def reg(icon, text, target, sid, keys, description):
-            ac = actions[sid] = QAction(QIcon(I(icon)), text, self) if icon else QAction(text, self)
+            if not isinstance(icon, QIcon):
+                icon = QIcon(I(icon))
+            ac = actions[sid] = QAction(icon, text, self) if icon else QAction(text, self)
             ac.setObjectName('action-' + sid)
             if target is not None:
                 ac.triggered.connect(target)
@@ -197,17 +283,22 @@ class Main(MainWindow):
             self.addAction(ac)
             return ac
 
-        self.action_new_file = reg('document-new.png', _('&New file'), self.boss.add_file, 'new-file', (), _('Create a new file in the current book'))
+        self.action_new_file = reg('document-new.png', _('&New file (images/fonts/HTML/etc.)'), self.boss.add_file,
+                                   'new-file', (), _('Create a new file in the current book'))
+        self.action_import_files = reg(None, _('&Import files into book'), self.boss.add_files, 'new-files', (), _('Import files into book'))
         self.action_open_book = reg('document_open.png', _('Open &book'), self.boss.open_book, 'open-book', 'Ctrl+O', _('Open a new book'))
-        self.action_global_undo = reg('back.png', _('&Revert to before'), self.boss.do_global_undo, 'global-undo', 'Ctrl+Left',
+        # Qt does not generate shortcut overrides for cmd+arrow on os x which
+        # means these shortcuts interfere with editing
+        self.action_global_undo = reg('back.png', _('&Revert to before'), self.boss.do_global_undo, 'global-undo', () if isosx else 'Ctrl+Left',
                                       _('Revert book to before the last action (Undo)'))
-        self.action_global_redo = reg('forward.png', _('&Revert to after'), self.boss.do_global_redo, 'global-redo', 'Ctrl+Right',
+        self.action_global_redo = reg('forward.png', _('&Revert to after'), self.boss.do_global_redo, 'global-redo', () if isosx else 'Ctrl+Right',
                                       _('Revert book state to after the next action (Redo)'))
         self.action_save = reg('save.png', _('&Save'), self.boss.save_book, 'save-book', 'Ctrl+S', _('Save book'))
         self.action_save.setEnabled(False)
         self.action_save_copy = reg('save.png', _('Save a &copy'), self.boss.save_copy, 'save-copy', 'Ctrl+Alt+S', _('Save a copy of the book'))
         self.action_quit = reg('quit.png', _('&Quit'), self.boss.quit, 'quit', 'Ctrl+Q', _('Quit'))
         self.action_preferences = reg('config.png', _('&Preferences'), self.boss.preferences, 'preferences', 'Ctrl+P', _('Preferences'))
+        self.action_new_book = reg('book.png', _('Create &new, empty book'), self.boss.new_book, 'new-book', (), _('Create a new, empty book'))
 
         # Editor actions
         group = _('Editor actions')
@@ -226,17 +317,27 @@ class Main(MainWindow):
         self.action_editor_undo.setEnabled(False)
         self.action_editor_redo.setEnabled(False)
 
+        def ereg(icon, text, target, sid, keys, description):
+            return reg(icon, text, partial(self.boss.editor_action, target), sid, keys, description)
+        register_text_editor_actions(ereg, self.palette())
+
         # Tool actions
         group = _('Tools')
         self.action_toc = reg('toc.png', _('&Edit Table of Contents'), self.boss.edit_toc, 'edit-toc', (), _('Edit Table of Contents'))
+        self.action_inline_toc = reg('chapters.png', _('&Insert inline Table of Contents'),
+                                     self.boss.insert_inline_toc, 'insert-inline-toc', (), _('Insert inline Table of Contents'))
         self.action_fix_html_current = reg('html-fix.png', _('&Fix HTML'), partial(self.boss.fix_html, True), 'fix-html-current', (),
                                            _('Fix HTML in the current file'))
         self.action_fix_html_all = reg('html-fix.png', _('&Fix HTML - all files'), partial(self.boss.fix_html, False), 'fix-html-all', (),
                                        _('Fix HTML in all files'))
-        self.action_pretty_current = reg('format-justify-fill.png', _('&Beautify current file'), partial(self.boss.pretty_print, True), 'pretty-current', (),
+        self.action_pretty_current = reg('beautify.png', _('&Beautify current file'), partial(self.boss.pretty_print, True), 'pretty-current', (),
                                            _('Beautify current file'))
-        self.action_pretty_all = reg('format-justify-fill.png', _('&Beautify all files'), partial(self.boss.pretty_print, False), 'pretty-all', (),
+        self.action_pretty_all = reg('beautify.png', _('&Beautify all files'), partial(self.boss.pretty_print, False), 'pretty-all', (),
                                        _('Beautify all files'))
+        self.action_insert_char = reg('character-set.png', _('&Insert special character'), self.boss.insert_character, 'insert-character', (),
+                                      _('Insert special character'))
+        self.action_rationalize_folders = reg('mimetypes/dir.png', _('&Arrange into folders'), self.boss.rationalize_folders, 'rationalize-folders', (),
+                                      _('Arrange into folders'))
 
         # Polish actions
         group = _('Polish Book')
@@ -249,6 +350,9 @@ class Main(MainWindow):
         self.action_smarten_punctuation = reg(
             'smarten-punctuation.png', _('&Smarten punctuation'), partial(
                 self.boss.polish, 'smarten_punctuation', _('Smarten punctuation')), 'smarten-punctuation', (), _('Smarten punctuation'))
+        self.action_remove_unused_css = reg(
+            'edit-clear.png', _('Remove &unused CSS rules'), partial(
+                self.boss.polish, 'remove_unused_css', _('Remove unused CSS rules')), 'remove-unused-css', (), _('Remove unused CSS rules'))
 
         # Preview actions
         group = _('Preview')
@@ -283,6 +387,14 @@ class Main(MainWindow):
         self.action_mark = reg(None, _('&Mark selected text'), self.boss.mark_selected_text, 'mark-selected-text', ('Ctrl+Shift+M',), _('Mark selected text'))
         self.action_go_to_line = reg(None, _('Go to &line'), self.boss.go_to_line_number, 'go-to-line-number', ('Ctrl+.',), _('Go to line number'))
 
+        # Check Book actions
+        group = _('Check Book')
+        self.action_check_book = reg('debug.png', _('&Check Book'), self.boss.check_requested, 'check-book', ('F7'), _('Check book for errors'))
+        self.action_check_book_next = reg('forward.png', _('&Next error'), partial(
+            self.check_book.next_error, delta=1), 'check-book-next', ('Ctrl+F7'), _('Show next error'))
+        self.action_check_book_previous = reg('back.png', _('&Previous error'), partial(
+            self.check_book.next_error, delta=-1), 'check-book-previous', ('Ctrl+Shift+F7'), _('Show previous error'))
+
         # Miscellaneous actions
         group = _('Miscellaneous')
         self.action_create_checkpoint = reg(
@@ -294,6 +406,17 @@ class Main(MainWindow):
         self.action_close_all_but_current_tab = reg(
             'edit-clear.png', _('&Close other tabs'), self.central.close_all_but_current_editor, 'close-all-but-current-tab', 'Ctrl+Alt+W', _(
                 'Close all tabs except the current tab'))
+        self.action_help = reg(
+            'help.png', _('User &Manual'), lambda : open_url(QUrl('http://manual.calibre-ebook.com/edit.html')), 'user-manual', 'F1', _(
+                'Show User Manual'))
+        self.action_browse_images = reg(
+            'view-image.png', _('&Browse images in book'), self.boss.browse_images, 'browse-images', (), _(
+                'Browse images in the books visually'))
+        self.action_multiple_split = reg(
+            'auto_author_sort.png', _('&Split at multiple locations'), self.boss.multisplit, 'multisplit', (), _(
+                'Split HTML file at multiple locations'))
+        self.action_compare_book = reg('diff.png', _('&Compare to another book'), self.boss.compare_book, 'compare-book', (), _(
+            'Compare to another book'))
 
     def create_menubar(self):
         p, q = self.create_application_menubar()
@@ -303,13 +426,16 @@ class Main(MainWindow):
 
         f = b.addMenu(_('&File'))
         f.addAction(self.action_new_file)
+        f.addAction(self.action_import_files)
         f.addAction(self.action_open_book)
+        f.addAction(self.action_new_book)
         self.recent_books_menu = f.addMenu(_('&Recently opened books'))
         self.update_recent_books()
         f.addSeparator()
         f.addAction(self.action_save)
         f.addAction(self.action_save_copy)
         f.addSeparator()
+        f.addAction(self.action_compare_book)
         f.addAction(self.action_quit)
 
         e = b.addMenu(_('&Edit'))
@@ -323,16 +449,22 @@ class Main(MainWindow):
         e.addAction(self.action_editor_cut)
         e.addAction(self.action_editor_copy)
         e.addAction(self.action_editor_paste)
+        e.addAction(self.action_insert_char)
         e.addSeparator()
         e.addAction(self.action_preferences)
 
         e = b.addMenu(_('&Tools'))
-        e.addAction(self.action_toc)
+        tm = e.addMenu(_('Table of Contents'))
+        tm.addAction(self.action_toc)
+        tm.addAction(self.action_inline_toc)
         e.addAction(self.action_embed_fonts)
         e.addAction(self.action_subset_fonts)
         e.addAction(self.action_smarten_punctuation)
+        e.addAction(self.action_remove_unused_css)
         e.addAction(self.action_fix_html_all)
         e.addAction(self.action_pretty_all)
+        e.addAction(self.action_rationalize_folders)
+        e.addAction(self.action_check_book)
 
         e = b.addMenu(_('&View'))
         t = e.addMenu(_('Tool&bars'))
@@ -342,6 +474,7 @@ class Main(MainWindow):
                 e.addAction(ac)
             elif name.endswith('-bar'):
                 t.addAction(ac)
+        e.addAction(self.action_browse_images)
         e.addSeparator()
         e.addAction(self.action_close_current_tab)
         e.addAction(self.action_close_all_but_current_tab)
@@ -364,6 +497,12 @@ class Main(MainWindow):
         e.addSeparator()
         a(self.action_go_to_line)
 
+        e = b.addMenu(_('&Help'))
+        a = e.addAction
+        a(self.action_help)
+        a(QIcon(I('donate.png')), _('Donate to support calibre development'), open_donate)
+        a(self.action_preferences)
+
     def update_recent_books(self):
         m = self.recent_books_menu
         m.clear()
@@ -381,11 +520,27 @@ class Main(MainWindow):
             return b
 
         a = create(_('Book tool bar'), 'global').addAction
-        for x in ('new_file', 'open_book', 'global_undo', 'global_redo', 'save', 'create_checkpoint', 'toc'):
+        for x in ('new_file', 'open_book', None, 'global_undo', 'global_redo', 'create_checkpoint', 'save', None, 'toc', 'check_book'):
+            if x is None:
+                self.global_bar.addSeparator()
+                continue
             a(getattr(self, 'action_' + x))
+        self.donate_button = b = ThrobbingButton(self)
+        b.clicked.connect(open_donate)
+        b.setAutoRaise(True)
+        self.donate_widget = w = create_donate_widget(b)
+        if hasattr(w, 'filler'):
+            w.filler.setVisible(False)
+        b.set_normal_icon_size(self.global_bar.iconSize().width(), self.global_bar.iconSize().height())
+        b.setIcon(QIcon(I('donate.png')))
+        b.setToolTip(_('Donate to support calibre development'))
+        QTimer.singleShot(10, b.start_animation)
+        self.global_bar.addWidget(w)
+        self.global_bar.addAction(self.action_insert_char)
+        a(self.action_help)
 
         a = create(_('Polish book tool bar'), 'polish').addAction
-        for x in ('embed_fonts', 'subset_fonts', 'smarten_punctuation'):
+        for x in ('embed_fonts', 'subset_fonts', 'smarten_punctuation', 'remove_unused_css'):
             a(getattr(self, 'action_' + x))
 
     def create_docks(self):
@@ -402,30 +557,53 @@ class Main(MainWindow):
             setattr(self, oname.replace('-', '_'), d)
             return d
 
-        d = create(_('&Files Browser'), 'files-browser')
+        d = create(_('Files Browser'), 'files-browser')
         d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea)
         self.file_list = FileListWidget(d)
         d.setWidget(self.file_list)
         self.addDockWidget(Qt.LeftDockWidgetArea, d)
 
-        d = create(_('File &Preview'), 'preview')
+        d = create(_('File Preview'), 'preview')
         d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea)
         self.preview = Preview(d)
         d.setWidget(self.preview)
         self.addDockWidget(Qt.RightDockWidgetArea, d)
 
-        d = create(_('&Inspector'), 'inspector')
+        d = create(_('Check Book'), 'check-book')
+        d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.BottomDockWidgetArea | Qt.TopDockWidgetArea)
+        d.setWidget(self.check_book)
+        self.addDockWidget(Qt.TopDockWidgetArea, d)
+        d.close()  # By default the check window is closed
+
+        d = create(_('Inspector'), 'inspector')
         d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.BottomDockWidgetArea | Qt.TopDockWidgetArea)
         d.setWidget(self.preview.inspector)
         self.preview.inspector.setParent(d)
         self.addDockWidget(Qt.BottomDockWidgetArea, d)
+        d.close()  # By default the inspector window is closed
+        d.setFeatures(d.DockWidgetClosable | d.DockWidgetMovable)  # QWebInspector does not work in a floating dock
+
+        d = create(_('Table of Contents'), 'toc-viewer')
+        d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.BottomDockWidgetArea | Qt.TopDockWidgetArea)
+        d.setWidget(self.toc_view)
+        self.addDockWidget(Qt.LeftDockWidgetArea, d)
+        d.close()  # Hidden by default
+        d.visibilityChanged.connect(self.toc_view.visibility_changed)
+
+        d = create(_('Checkpoints'), 'checkpoints')
+        d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.BottomDockWidgetArea | Qt.TopDockWidgetArea)
+        self.checkpoints = CheckpointView(self.boss.global_undo, parent=d)
+        d.setWidget(self.checkpoints)
+        self.addDockWidget(Qt.LeftDockWidgetArea, d)
+        d.close()  # Hidden by default
 
     def resizeEvent(self, ev):
         self.blocking_job.resize(ev.size())
         return super(Main, self).resizeEvent(ev)
 
     def update_window_title(self):
-        self.setWindowTitle(self.current_metadata.title + ' [%s] - %s' %(current_container().book_type.upper(), self.APP_NAME))
+        fname = os.path.basename(current_container().path_to_ebook)
+        self.setWindowTitle(self.current_metadata.title + ' [%s] :: %s :: %s' %(current_container().book_type.upper(), fname, self.APP_NAME))
 
     def closeEvent(self, e):
         if not self.boss.confirm_quit():
@@ -442,6 +620,7 @@ class Main(MainWindow):
         tprefs.set('main_window_geometry', bytearray(self.saveGeometry()))
         tprefs.set('main_window_state', bytearray(self.saveState(self.STATE_VERSION)))
         self.central.save_state()
+        self.check_book.save_state()
 
     def restore_state(self):
         geom = tprefs.get('main_window_geometry', None)
