@@ -134,8 +134,29 @@ class Rule(object): # {{{
 
     def date_condition(self, col, action, val):
         if action == 'count_days':
-            return (("cmp(add(%s, 1), days_between(today(), format_date(raw_field('%s'), 'yyyy-MM-dd')), '', '1', '1')")
-                     %(val, col))
+            return (("test(field('%s'), cmp(%s, "
+                            "days_between(format_date(today(), 'yyyy-MM-dd'),"
+                            "format_date(raw_field('%s'), 'yyyy-MM-dd')), '', '1', '1'), '')")
+                     %(col, val, col))
+        if action == 'older count days':
+            return (("test(field('%s'), cmp(%s, "
+                            "days_between(format_date(today(), 'yyyy-MM-dd'),"
+                            "format_date(raw_field('%s'), 'yyyy-MM-dd')), '1', '', ''), '')")
+                     %(col, val, col))
+        if action == 'older future days':
+            return (("test(field('%s'), cmp(%s, "
+                            "days_between(format_date(raw_field('%s'), 'yyyy-MM-dd'), "
+                            "format_date(today(), 'yyyy-MM-dd')), '', '1', '1'), '')")
+                     %(col, val, col))
+        if action == 'newer future days':
+            return (("test(field('%s'), cmp(%s, "
+                            "days_between(format_date(raw_field('%s'), 'yyyy-MM-dd'), "
+                            "format_date(today(), 'yyyy-MM-dd')), '1', '', ''), '')")
+                     %(col, val, col))
+        if action == 'is set':
+            return (("test(field('%s'), '1', '')"%(col)))
+        if action == 'is not set':
+            return (("test(field('%s'), '', '1')"%(col)))
         lt, eq, gt = {
                 'eq': ('', '1', ''),
                 'lt': ('1', '', ''),
