@@ -83,7 +83,7 @@ def _builtin_field_metadata():
                            'datatype':'series',
                            'is_multiple':{},
                            'kind':'field',
-                           'name':ngettext('Series', 'Series', 2),
+                           'name':ngettext('Series', 'Series', 1),
                            'search_terms':['series'],
                            'is_custom':False,
                            'is_category':True,
@@ -107,7 +107,7 @@ def _builtin_field_metadata():
                            'datatype':'text',
                            'is_multiple':{},
                            'kind':'field',
-                           'name':_('Publishers'),
+                           'name':_('Publisher'),
                            'search_terms':['publisher'],
                            'is_custom':False,
                            'is_category':True,
@@ -452,7 +452,7 @@ class FieldMetadata(dict):
         return [k for k in self._tb_cats.keys()
                 if self._tb_cats[k]['kind']=='field' and
                    self._tb_cats[k]['datatype'] is not None and
-                   k not in ('au_map', 'marked', 'ondevice', 'cover') and
+                   k not in ('au_map', 'marked', 'ondevice', 'cover', 'series_sort') and
                    not self.is_series_index(k)]
 
     def standard_field_keys(self):
