@@ -23,7 +23,7 @@ from calibre.library.server import custom_fields_to_display
 from calibre import force_unicode, isbytestring
 from calibre.library.field_metadata import category_icon_map
 
-class Endpoint(object): # {{{
+class Endpoint(object):  # {{{
     'Manage mime-type json serialization, etc.'
 
     def __init__(self, mimetype='application/json; charset=utf-8',
@@ -55,7 +55,7 @@ class Endpoint(object): # {{{
         return wrapper
 # }}}
 
-def category_icon(category, meta): # {{{
+def category_icon(category, meta):  # {{{
     if category in category_icon_map:
         icon = category_icon_map[category]
     elif meta['is_custom']:
@@ -117,7 +117,6 @@ class AjaxServer(object):
         # Search
         connect('ajax_search', base_href+'/search', self.ajax_search)
 
-
     # Get book metadata {{{
     def ajax_book_to_json(self, book_id, get_category_urls=True,
                           device_compatible=False):
@@ -214,7 +213,7 @@ class AjaxServer(object):
                 book_id = int(book_id)
             data, last_modified = self.ajax_book_to_json(book_id,
                     get_category_urls=category_urls.lower()=='true',
-                    device_compatible=device_compatible.lower()=='true');
+                    device_compatible=device_compatible.lower()=='true')
         except:
             raise cherrypy.HTTPError(404, 'No book with id: %r'%book_id)
 
@@ -291,7 +290,6 @@ class AjaxServer(object):
 
         displayed_custom_fields = custom_fields_to_display(self.db)
 
-
         for category in sorted(categories, key=lambda x: sort_key(getter(x))):
             if len(categories[category]) == 0:
                 continue
@@ -314,7 +312,7 @@ class AjaxServer(object):
         ans = [{'url':k, 'name':v[0], 'icon':v[1], 'is_category':True}
                 for k, v in ans.iteritems()]
         ans.sort(key=lambda x: sort_key(x['name']))
-        for name, url, icon in  [
+        for name, url, icon in [
                 (_('All books'), 'allbooks', 'book.png'),
                 (_('Newest'), 'newest', 'forward.png'),
                 ]:
@@ -505,13 +503,12 @@ class AjaxServer(object):
                 'items':items,
         }
 
-
     # }}}
 
     # Books in the specified category {{{
     @Endpoint()
     def ajax_books_in(self, category, item, sort='title', num=25, offset=0,
-            sort_order='asc'):
+            sort_order='asc', get_additional_fields=''):
         '''
         Return the books (as list of ids) present in the specified category.
         '''
@@ -562,13 +559,26 @@ class AjaxServer(object):
                 only_ids=ids)
         total_num = len(ids)
         ids = ids[offset:offset+num]
-        return {
+
+        result = {
                 'total_num': total_num, 'sort_order':sort_order,
                 'offset':offset, 'num':len(ids), 'sort':sort,
                 'base_url':absurl(self.opts.url_prefix, '/ajax/books_in/%s/%s'%(category, item)),
                 'book_ids':ids
         }
 
+        if get_additional_fields:
+            additional_fields = {}
+            for field in get_additional_fields.split(','):
+                field = field.strip()
+                if field:
+                    flist = additional_fields[field] = []
+                    for id_ in ids:
+                        flist.append(self.db.new_api.field_for(field, id_,
+                                                               default_value=None))
+            if additional_fields:
+                result['additional_fields'] = additional_fields
+        return result
 
     # }}}
 
@@ -594,8 +604,7 @@ class AjaxServer(object):
 
         if isbytestring(query):
             query = query.decode('UTF-8')
-        ids = self.db.search_getting_ids(query.strip(), self.search_restriction)
-        ids = list(ids)
+        ids = list(self.search_for_books(query))
         self.db.data.multisort(fields=[(sfield, sort_order == 'asc')], subsort=True,
                 only_ids=ids)
         total_num = len(ids)
