@@ -116,7 +116,7 @@ def main(args=sys.argv):
         print('No saved library path. Use the --with-library option'
                 ' to specify the path to the library you want to use.')
         return 1
-    db = LibraryDatabase(opts.with_library)
+    db = LibraryDatabase(os.path.expanduser(opts.with_library))
     server = LibraryServer(db, opts, show_tracebacks=opts.develop)
     server.start()
     return 0
