@@ -73,7 +73,8 @@ def fc_list():
             try:
                 ans.append(d.decode(filesystem_encoding))
             except ValueError:
-                return default_font_dirs
+                prints('Ignoring undecodeable font path: %r' % d)
+                continue
     end(str_list)
     if len(ans) < 3:
         return default_font_dirs()
