@@ -661,6 +661,17 @@ icu_set_default_encoding(PyObject *self, PyObject *args) {
 }
 // }}}
 
+// set_default_encoding {{{
+static PyObject *
+icu_set_filesystem_encoding(PyObject *self, PyObject *args) {
+    char *encoding;
+    if (!PyArg_ParseTuple(args, "s:setfilesystemencoding", &encoding))
+        return NULL;
+    Py_FileSystemDefaultEncoding = strdup(encoding);
+    Py_RETURN_NONE;
+
+}
+// }}}
 // set_default_encoding {{{
 static PyObject *
 icu_get_available_transliterators(PyObject *self, PyObject *args) {
@@ -707,6 +718,10 @@ static PyMethodDef icu_methods[] = {
         "set_default_encoding(encoding) -> Set the default encoding for the python unicode implementation."
     },
 
+    {"set_filesystem_encoding", icu_set_filesystem_encoding, METH_VARARGS,
+        "set_filesystem_encoding(encoding) -> Set the filesystem encoding for python."
+    },
+
     {"get_available_transliterators", icu_get_available_transliterators, METH_VARARGS,
         "get_available_transliterators() -> Return list of available transliterators. This list is rather limited on OS X."
     },
