@@ -25,8 +25,8 @@ PARALLEL_FUNCS = {
       'ebook-viewer'    :
         ('calibre.gui2.viewer.main', 'main', None),
 
-      'ebook-tweak' :
-        ('calibre.gui2.tweak_book.main', 'main', None),
+      'ebook-edit' :
+        ('calibre.gui2.tweak_book.main', 'gui_main', None),
 
       'render_pages' :
         ('calibre.ebooks.comic.input', 'render_pages', 'notification'),
